@@ -6,31 +6,27 @@ class Projects::RawController < Projects::ApplicationController
   include SendsBlob
   include StaticObjectExternalStorage
 
-  skip_before_action :default_cache_headers, only: :show
-
   prepend_before_action(only: [:show]) { authenticate_sessionless_user!(:blob) }
 
-  before_action :set_ref_and_path
+  before_action :assign_ref_vars
   before_action :require_non_empty_project
-  before_action :authorize_download_code!
+  before_action :authorize_read_code!
   before_action :check_show_rate_limit!, only: [:show], unless: :external_storage_request?
   before_action :redirect_to_external_storage, only: :show, if: :static_objects_external_storage_enabled?
 
   feature_category :source_code_management
 
   def show
-    @blob = @repository.blob_at(@ref, @path, limit: Gitlab::Git::Blob::LFS_POINTER_MAX_SIZE)
+    @blob = @repository.blob_at(ref, @path, limit: Gitlab::Git::Blob::LFS_POINTER_MAX_SIZE)
 
-    send_blob(@repository, @blob, inline: (params[:inline] != 'false'), allow_caching: Guest.can?(:download_code, @project))
+    send_blob(@repository, @blob, inline: (params[:inline] != 'false'), allow_caching:
+::Users::Anonymous.can?(:read_code, @project))
   end
 
   private
 
-  def set_ref_and_path
-    # This bypasses assign_ref_vars to avoid a Gitaly FindCommit lookup.
-    # We don't need to find the commit to either rate limit or send the
-    # blob.
-    @ref, @path = extract_ref(get_id)
+  def ref
+    @fully_qualified_ref || @ref
   end
 
   def check_show_rate_limit!
