@@ -19,9 +19,6 @@ class Projects::TreeController < Projects::ApplicationController
 
   before_action do
     push_frontend_feature_flag(:inline_blame, @project)
-    push_frontend_feature_flag(:blob_repository_vue_header_app, @project)
-    push_frontend_feature_flag(:blob_overflow_menu, current_user)
-    push_frontend_feature_flag(:filter_blob_path, current_user)
     push_licensed_feature(:file_locks) if @project.licensed_feature_available?(:file_locks)
     push_frontend_feature_flag(:directory_code_dropdown_updates, current_user)
     push_frontend_feature_flag(:repository_file_tree_browser, @project)
