@@ -1,9 +1,10 @@
 # frozen_string_literal: true
 
 class Projects::VariablesController < Projects::ApplicationController
-  before_action :authorize_admin_build!
+  before_action :authorize_admin_build!, except: :update
+  before_action :authorize_admin_cicd_variables!, only: :update
 
-  feature_category :pipeline_authoring
+  feature_category :pipeline_composition
 
   urgency :low, [:show, :update]
 
@@ -47,6 +48,6 @@ class Projects::VariablesController < Projects::ApplicationController
   end
 
   def variable_params_attributes
-    %i[id variable_type key secret_value protected masked environment_scope _destroy]
+    %i[id variable_type key description secret_value protected masked hidden raw environment_scope _destroy]
   end
 end
