@@ -62,6 +62,8 @@ class SearchController < ApplicationController
       current_user: current_user
     ).fabricate!
 
+    @scope = @search_service_presenter.scope
+    @search_type = search_type
     return unless search_term_valid? && search_type_valid?
 
     return if check_single_commit_result?
@@ -70,8 +72,6 @@ class SearchController < ApplicationController
     @sort = params[:sort] || default_sort
 
     @search_level = @search_service_presenter.level
-    @search_type = search_type
-    @scope = @search_service_presenter.scope
 
     # separate following lines to method that is conditionally triggered when not zoekt multi-result search
     haml_search_results unless multi_match?(scope: @scope, search_type: search_type)
@@ -145,7 +145,7 @@ class SearchController < ApplicationController
       return true
     end
 
-    return true if ::Feature.disabled?(:allow_anonymous_searches, type: :ops)
+    return true unless ::Gitlab::CurrentSettings.anonymous_searches_allowed?
 
     false
   end
@@ -283,7 +283,6 @@ class SearchController < ApplicationController
       metadata['meta.search.filters.confidential'] = filter_params[:confidential]
       metadata['meta.search.filters.state'] = filter_params[:state]
       metadata['meta.search.force_search_results'] = params[:force_search_results]
-      metadata['meta.search.project_ids'] = params[:project_ids]
       metadata['meta.search.filters.language'] = filter_params[:language]
       metadata['meta.search.type'] = @search_type if @search_type.present?
       metadata['meta.search.level'] = @search_level if @search_level.present?
