@@ -10,15 +10,15 @@ module Mutations
       NB
 
       field :note,
-            Types::Notes::NoteType,
-            null: true,
-            description: 'Note after mutation.'
+        Types::Notes::NoteType,
+        null: true, scopes: [:api, :ai_workflows],
+        description: 'Note after mutation.'
 
-      private
-
-      def find_object(id:)
-        GitlabSchema.find_by_gid(id)
-      end
+      field :quick_actions_status,
+        Types::Notes::QuickActionsStatusType,
+        null: true,
+        description: 'Status of quick actions after mutation.',
+        skip_type_authorization: [:read_note]
     end
   end
 end
