@@ -5,22 +5,21 @@ module Mutations
     class BulkDestroy < ::Mutations::BaseMutation
       graphql_name 'DestroyPackages'
 
-      MAX_PACKAGES = 20
+      MAX_PACKAGES = 100
       TOO_MANY_IDS_ERROR = "Cannot delete more than #{MAX_PACKAGES} packages"
 
       argument :ids,
-               [::Types::GlobalIDType[::Packages::Package]],
-               required: true,
-               description: "Global IDs of the Packages. Max #{MAX_PACKAGES}"
+        [::Types::GlobalIDType[::Packages::Package]],
+        required: true,
+        description: "Global IDs of the Packages. Max #{MAX_PACKAGES}"
 
       def resolve(ids:)
         raise_resource_not_available_error!(TOO_MANY_IDS_ERROR) if ids.size > MAX_PACKAGES
 
-        ids = GitlabSchema.parse_gids(ids, expected_type: ::Packages::Package)
-                          .map(&:model_id)
+        model_ids = ids.map(&:model_id)
 
         service = ::Packages::MarkPackagesForDestructionService.new(
-          packages: packages_from(ids),
+          packages: packages_from(model_ids),
           current_user: current_user
         )
         result = service.execute
