@@ -2,22 +2,23 @@
 
 module Mutations
   module Todos
-    class Create < ::Mutations::Todos::Base
+    class Create < ::Mutations::BaseMutation
       graphql_name 'TodoCreate'
 
       authorize :create_todo
 
       argument :target_id,
-               Types::GlobalIDType[Todoable],
-               required: true,
-               description: "Global ID of the to-do item's parent. Issues, merge requests, designs, and epics are supported."
+        Types::GlobalIDType[Todoable],
+        required: true,
+        description: "Global ID of the to-do item's parent. Issues, " \
+          "merge requests, designs, and epics are supported."
 
       field :todo, Types::TodoType,
-            null: true,
-            description: 'To-do item created.'
+        null: true,
+        description: 'To-do item created.'
 
       def resolve(target_id:)
-        target = authorized_find!(target_id)
+        target = authorized_find!(id: target_id)
 
         todo = TodoService.new.mark_todo(target, current_user)&.first
         errors = errors_on_object(todo) if todo
@@ -27,12 +28,6 @@ module Mutations
           errors: errors
         }
       end
-
-      private
-
-      def find_object(id)
-        GitlabSchema.find_by_gid(id)
-      end
     end
   end
 end
