@@ -29,13 +29,6 @@ module Resolvers
           widget_definitions: :enabled_widget_definitions
         }
       end
-
-      def nested_preloads
-        {
-          widget_definitions: { allowed_child_types: :allowed_child_types_by_name,
-                                allowed_parent_types: :allowed_parent_types_by_name }
-        }
-      end
     end
   end
 end
