@@ -4,7 +4,7 @@ module Types
   class GroupType < NamespaceType
     graphql_name 'Group'
 
-    include ::NamespacesHelper
+    include ::Namespaces::DeletableHelper
 
     implements ::Types::Namespaces::GroupInterface
 
@@ -17,11 +17,20 @@ module Types
       null: false,
       description: 'Web URL of the group.'
 
+    field :web_path,
+      GraphQL::Types::String,
+      null: false,
+      description: 'Web path of the group.'
+
     field :organization_edit_path, GraphQL::Types::String,
       null: true,
       description: 'Path for editing group at the organization level.',
       experiment: { milestone: '17.1' }
 
+    field :edit_path, GraphQL::Types::String,
+      null: false,
+      description: 'Path for editing group.'
+
     field :avatar_url,
       type: GraphQL::Types::String,
       null: true,
@@ -239,11 +248,21 @@ module Types
       complexity: 5,
       resolver: Resolvers::NestedGroupsResolver
 
+    field :shared_groups, Types::GroupType.connection_type,
+      null: true,
+      description: 'List of shared groups this group was invited to.',
+      resolver: Resolvers::Namespaces::SharedGroupsResolver
+
     field :descendant_groups_count,
       GraphQL::Types::Int,
       null: false,
       description: 'Count of direct descendant groups of the group.'
 
+    field :shared_projects, Types::ProjectType.connection_type,
+      null: true,
+      description: 'List of shared projects this group was invited to.',
+      resolver: Resolvers::Projects::SharedProjectsResolver
+
     field :group_members_count,
       GraphQL::Types::Int,
       null: false,
@@ -317,15 +336,13 @@ module Types
     field :work_item, Types::WorkItemType,
       resolver: Resolvers::Namespaces::WorkItemResolver,
       experiment: { milestone: '16.4' },
-      description: 'Find a work item by IID directly associated with the group. Returns `null` if the ' \
-        '`namespace_level_work_items` feature flag is disabled.'
+      description: 'Find a work item by IID directly associated with the group.'
 
     field :work_item_state_counts,
       Types::WorkItemStateCountsType,
       null: true,
       experiment: { milestone: '16.7' },
-      description: 'Counts of work items by state for the namespace. Returns `null` if the ' \
-        '`namespace_level_work_items` feature flag is disabled.',
+      description: 'Counts of work items by state for the namespace.',
       resolver: Resolvers::Namespaces::WorkItemStateCountsResolver
 
     field :autocomplete_users,
@@ -358,22 +375,47 @@ module Types
       description: 'Cluster agents associated with projects in the group and its subgroups.',
       resolver: ::Resolvers::Clusters::AgentsResolver
 
+    field :archived, GraphQL::Types::Boolean,
+      description: 'Indicates the archived status of the group.',
+      experiment: { milestone: '18.3' },
+      method: :self_or_ancestors_archived?
+
+    field :marked_for_deletion, GraphQL::Types::Boolean,
+      null: false,
+      description: 'Indicates if group or any ancestor is scheduled to be deleted.',
+      method: :scheduled_for_deletion_in_hierarchy_chain?,
+      experiment: { milestone: '18.2' }
+
     field :marked_for_deletion_on, ::Types::TimeType,
       null: true,
       description: 'Date when group was scheduled to be deleted.',
       experiment: { milestone: '16.11' }
 
-    field :is_adjourned_deletion_enabled, GraphQL::Types::Boolean,
-      null: false,
-      description: 'Indicates if delayed group deletion is enabled.',
-      method: :adjourned_deletion?,
-      experiment: { milestone: '16.11' }
-
     field :permanent_deletion_date, GraphQL::Types::String,
       null: true,
-      description: 'Date when group will be deleted if delayed group deletion is enabled.',
+      description: "For groups pending deletion, returns the group's scheduled deletion date. " \
+        'For groups not pending deletion, returns a theoretical date based on current settings ' \
+        'if marked for deletion today.',
       experiment: { milestone: '16.11' }
 
+    field :is_self_deletion_in_progress, GraphQL::Types::Boolean,
+      null: false,
+      description: 'Indicates if group deletion is in progress.',
+      method: :self_deletion_in_progress?,
+      experiment: { milestone: '18.2' }
+
+    field :is_self_deletion_scheduled, GraphQL::Types::Boolean,
+      null: false,
+      description: 'Indicates if group deletion is scheduled.',
+      method: :self_deletion_scheduled?,
+      experiment: { milestone: '18.2' }
+
+    field :project_statistics, Types::Namespaces::ProjectStatisticsType,
+      method: :itself,
+      null: true,
+      description: 'Statistics of the projects in the group. Only available from [Query.groups](#querygroups).',
+      experiment: { milestone: '18.2' }
+
     def label(title:)
       BatchLoader::GraphQL.for(title).batch(key: group) do |titles, loader, args|
         LabelsFinder
@@ -470,15 +512,19 @@ module Types
     end
 
     def marked_for_deletion_on
-      return unless group.adjourned_deletion?
-
       group.marked_for_deletion_on
     end
 
     def permanent_deletion_date
-      return unless group.adjourned_deletion?
+      permanent_deletion_date_formatted(group) || permanent_deletion_date_formatted
+    end
 
-      permanent_deletion_date_formatted(Date.current)
+    def web_path
+      group.web_url(only_path: true)
+    end
+
+    def edit_path
+      ::Gitlab::Routing.url_helpers.edit_group_path(group)
     end
 
     private
