@@ -26,9 +26,15 @@ module Types
     mount_mutation Mutations::Security::CiConfiguration::ConfigureSast
     mount_mutation Mutations::Security::CiConfiguration::ConfigureSastIac
     mount_mutation Mutations::Security::CiConfiguration::ConfigureSecretDetection
-    mount_mutation Mutations::AlertManagement::PrometheusIntegration::Create
-    mount_mutation Mutations::AlertManagement::PrometheusIntegration::Update
-    mount_mutation Mutations::AlertManagement::PrometheusIntegration::ResetToken
+    mount_mutation Mutations::AlertManagement::PrometheusIntegration::Create, deprecated: {
+      reason: 'Use HttpIntegrationCreate', milestone: '18.2'
+    }
+    mount_mutation Mutations::AlertManagement::PrometheusIntegration::Update, deprecated: {
+      reason: 'Use HttpIntegrationUpdate', milestone: '18.2'
+    }
+    mount_mutation Mutations::AlertManagement::PrometheusIntegration::ResetToken, deprecated: {
+      reason: 'Use HttpIntegrationResetToken', milestone: '18.2'
+    }
     mount_mutation Mutations::AwardEmojis::Add
     mount_mutation Mutations::AwardEmojis::Remove
     mount_mutation Mutations::AwardEmojis::Toggle
@@ -65,6 +71,7 @@ module Types
     mount_mutation Mutations::Import::SourceUsers::CancelReassignment, experiment: { milestone: '17.2' }
     mount_mutation Mutations::Import::SourceUsers::KeepAllAsPlaceholder, experiment: { milestone: '17.6' }
     mount_mutation Mutations::Import::SourceUsers::KeepAsPlaceholder, experiment: { milestone: '17.2' }
+    mount_mutation Mutations::Import::SourceUsers::UndoKeepAsPlaceholder, experiment: { milestone: '18.4' }
     mount_mutation Mutations::Import::SourceUsers::Reassign, experiment: { milestone: '17.2' }
     mount_mutation Mutations::Import::SourceUsers::ResendNotification, experiment: { milestone: '17.2' }
     mount_mutation Mutations::IncidentManagement::TimelineEvent::Create, experiment: { milestone: '15.6' }
@@ -88,6 +95,7 @@ module Types
     mount_mutation Mutations::Issues::LinkAlerts
     mount_mutation Mutations::Issues::UnlinkAlert
     mount_mutation Mutations::Labels::Create
+    mount_mutation Mutations::Labels::Update
     mount_mutation Mutations::Members::Groups::BulkUpdate
     mount_mutation Mutations::Members::Projects::BulkUpdate
     mount_mutation Mutations::MergeRequests::Accept
@@ -111,11 +119,11 @@ module Types
     }
     mount_mutation Mutations::Notes::AbuseReport::Create
     mount_mutation Mutations::Notes::AbuseReport::Update, experiment: { milestone: '17.5' }
-    mount_mutation Mutations::Notes::Create::Note, calls_gitaly: true
+    mount_mutation Mutations::Notes::Create::Note, calls_gitaly: true, scopes: [:api, :ai_workflows]
     mount_mutation Mutations::Notes::Create::DiffNote, calls_gitaly: true
     mount_mutation Mutations::Notes::Create::ImageDiffNote, calls_gitaly: true
     mount_mutation Mutations::Notes::Create::Discussion, calls_gitaly: true
-    mount_mutation Mutations::Notes::Update::Note
+    mount_mutation Mutations::Notes::Update::Note, scopes: [:api, :ai_workflows]
     mount_mutation Mutations::Notes::Update::ImageDiffNote
     mount_mutation Mutations::Notes::ConvertToThread
     mount_mutation Mutations::Notes::RepositionImageDiffNote
@@ -188,6 +196,7 @@ module Types
     mount_mutation Mutations::Ci::JobTokenScope::UpdateJobTokenPolicies, experiment: { milestone: '17.6' }
     mount_mutation Mutations::Ci::JobTokenScope::AutopopulateAllowlist, experiment: { milestone: '17.9' }
     mount_mutation Mutations::Ci::JobTokenScope::ClearAllowlistAutopopulations, experiment: { milestone: '17.9' }
+    mount_mutation Mutations::Ci::Lint
     mount_mutation Mutations::Ci::NamespaceSettingsUpdate, experiment: { milestone: '17.9' }
     mount_mutation Mutations::Ci::Pipeline::Cancel
     mount_mutation Mutations::Ci::Pipeline::Create
@@ -202,17 +211,21 @@ module Types
     mount_mutation Mutations::Ci::PipelineTrigger::Delete, experiment: { milestone: '16.3' }
     mount_mutation Mutations::Ci::PipelineTrigger::Update, experiment: { milestone: '16.3' }
     mount_mutation Mutations::Ci::ProjectCiCdSettingsUpdate
+    mount_mutation Mutations::Ci::SafeDisablePipelineVariables
     mount_mutation Mutations::Ci::Runner::BulkDelete, experiment: { milestone: '15.3' }
     mount_mutation Mutations::Ci::Runner::BulkPause, experiment: { milestone: '17.11' }
     mount_mutation Mutations::Ci::Runner::Cache::Clear
     mount_mutation Mutations::Ci::Runner::Create, experiment: { milestone: '15.10' }
     mount_mutation Mutations::Ci::Runner::Delete
     mount_mutation Mutations::Ci::Runner::Update
+    mount_mutation Mutations::Ci::Runner::AssignToProject, experiment: { milestone: '18.1' }
+    mount_mutation Mutations::Ci::Runner::UnassignFromProject, experiment: { milestone: '18.1' }
     mount_mutation Mutations::Ci::RunnersRegistrationToken::Reset, deprecated: {
       reason: 'Underlying feature was deprecated in 15.6 and will be removed in 18.0',
       milestone: '17.7'
     }
     mount_mutation Mutations::Namespace::PackageSettings::Update
+    mount_mutation Mutations::Namespaces::RegenerateNewWorkItemEmailAddress, experiment: { milestone: '18.2' }
     mount_mutation Mutations::Groups::Update
     mount_mutation Mutations::UserCallouts::Create
     mount_mutation Mutations::UserPreferences::Update
@@ -226,22 +239,28 @@ module Types
     mount_mutation Mutations::Packages::DestroyFiles
     mount_mutation Mutations::Packages::Cleanup::Policy::Update
     mount_mutation Mutations::Echo
-    mount_mutation Mutations::WorkItems::Create, experiment: { milestone: '15.1' }
+    mount_mutation Mutations::WorkItems::Create, experiment: { milestone: '15.1' }, scopes: [:api, :ai_workflows]
     mount_mutation Mutations::WorkItems::CreateFromTask, experiment: { milestone: '15.1' }
     mount_mutation Mutations::WorkItems::Delete, experiment: { milestone: '15.1' }
-    mount_mutation Mutations::WorkItems::Update, experiment: { milestone: '15.1' }
+    mount_mutation Mutations::WorkItems::Update, experiment: { milestone: '15.1' }, scopes: [:api, :ai_workflows]
     mount_mutation Mutations::WorkItems::CSV::Export, experiment: { milestone: '15.10' }
+    mount_mutation Mutations::WorkItems::CSV::Import, experiment: { milestone: '18.2' }
     mount_mutation Mutations::WorkItems::Convert, experiment: { milestone: '15.11' }
     mount_mutation Mutations::WorkItems::LinkedItems::Add, experiment: { milestone: '16.3' }
     mount_mutation Mutations::WorkItems::LinkedItems::Remove, experiment: { milestone: '16.3' }
     mount_mutation Mutations::WorkItems::AddClosingMergeRequest, experiment: { milestone: '17.1' }
     mount_mutation Mutations::WorkItems::Hierarchy::Reorder, experiment: { milestone: '17.3' }
+    mount_mutation Mutations::WorkItems::Hierarchy::AddChildrenItems, experiment: { milestone: '18.2' }
     mount_mutation Mutations::WorkItems::BulkUpdate, experiment: { milestone: '17.4' }
+    mount_mutation Mutations::WorkItems::BulkMove, experiment: { milestone: '18.2' }
+    mount_mutation Mutations::WorkItems::Reorder, experiment: { milestone: '18.3' }
     mount_mutation Mutations::WorkItems::UserPreference::Update, experiment: { milestone: '17.10' }
     mount_mutation Mutations::Users::SavedReplies::Create
     mount_mutation Mutations::Users::SavedReplies::Update
     mount_mutation Mutations::Users::SavedReplies::Destroy
     mount_mutation Mutations::Pages::MarkOnboardingComplete
+    mount_mutation Mutations::Pages::SetPagesForceHttps
+    mount_mutation Mutations::Pages::SetPagesUseUniqueDomain
     mount_mutation Mutations::Uploads::Delete
     mount_mutation Mutations::Users::SetNamespaceCommitEmail
     mount_mutation Mutations::WorkItems::Subscribe, experiment: { milestone: '16.3' }
@@ -256,6 +275,7 @@ module Types
     mount_mutation Mutations::BranchRules::Delete, experiment: { milestone: '16.9' }
     mount_mutation Mutations::Pages::Deployment::Delete, experiment: { milestone: '17.1' }
     mount_mutation Mutations::Pages::Deployment::Restore, experiment: { milestone: '17.1' }
+    mount_mutation Mutations::Wikis::WikiPageSubscribe, experiment: { milestone: '18.1' }
   end
 end
 
