@@ -11,6 +11,14 @@ module Types
           value: 'conan',
           description: 'Packages of the Conan format.'
 
+        value 'HELM',
+          value: 'helm',
+          description: 'Packages of the Helm format.'
+
+        value 'GENERIC',
+          value: 'generic',
+          description: 'Packages of the Generic format.'
+
         value 'MAVEN',
           value: 'maven',
           description: 'Packages of the Maven format.'
@@ -21,9 +29,7 @@ module Types
 
         value 'NUGET',
           value: 'nuget',
-          experiment: { milestone: '18.0' },
-          description: 'Packages of the NuGet format. ' \
-            'Available only when feature flag `packages_protected_packages_nuget` is enabled.'
+          description: 'Packages of the NuGet format.'
 
         value 'PYPI',
           value: 'pypi',
