@@ -74,6 +74,13 @@ module ApplicationSettingsHelper
 
   def global_search_settings_checkboxes(form)
     [
+      form.gitlab_ui_checkbox_component(
+        :anonymous_searches_allowed,
+        _("Allow unauthenticated users to use search"),
+        checkbox_options: {
+          checked: @application_setting.anonymous_searches_allowed, multiple: false
+        }
+      ),
       form.gitlab_ui_checkbox_component(
         :global_search_block_anonymous_searches_enabled,
         _("Restrict global search to authenticated users only"),
@@ -141,14 +148,18 @@ module ApplicationSettingsHelper
   end
 
   def import_sources_checkboxes(form)
-    Gitlab::ImportSources.options.map do |name, source|
-      checked = @application_setting.import_sources.include?(source)
+    import_sources_without_templates = Gitlab::ImportSources.import_table.reject do |importer|
+      Gitlab::ImportSources.template?(importer.name)
+    end
+
+    import_sources_without_templates.map do |source|
+      checked = @application_setting.import_sources.include?(source.name)
 
       form.gitlab_ui_checkbox_component(
         :import_sources,
-        name,
+        source.title,
         checkbox_options: { checked: checked, multiple: true, autocomplete: 'off' },
-        checked_value: source,
+        checked_value: source.name,
         unchecked_value: nil
       )
     end
@@ -290,6 +301,7 @@ module ApplicationSettingsHelper
       :default_projects_limit,
       :default_snippet_visibility,
       :default_syntax_highlighting_theme,
+      :default_dark_syntax_highlighting_theme,
       :delete_inactive_projects,
       :deletion_adjourned_period,
       :deny_all_requests_except_allowed,
@@ -320,6 +332,7 @@ module ApplicationSettingsHelper
       :enabled_git_access_protocol,
       :enforce_ci_inbound_job_token_scope_enabled,
       :enforce_email_subaddress_restrictions,
+      :require_email_verification_on_account_locked,
       :enforce_terms,
       :error_tracking_enabled,
       :error_tracking_api_url,
@@ -352,6 +365,7 @@ module ApplicationSettingsHelper
       :housekeeping_optimize_repository_period,
       :html_emails_enabled,
       :import_sources,
+      :inactive_resource_access_tokens_delete_after_days,
       :inactive_projects_delete_after_months,
       :inactive_projects_min_size_mb,
       :inactive_projects_send_warning_email_after_months,
@@ -369,6 +383,8 @@ module ApplicationSettingsHelper
       :max_export_size,
       :max_github_response_size_limit,
       :max_github_response_json_value_count,
+      :max_http_decompressed_size,
+      :max_http_response_size_limit,
       :max_import_size,
       :max_import_remote_file_size,
       :max_login_attempts,
@@ -383,6 +399,7 @@ module ApplicationSettingsHelper
       :notify_on_unknown_sign_in,
       :organization_cluster_agent_authorization_enabled,
       :pages_domain_verification_enabled,
+      :pages_unique_domain_default_enabled,
       :password_authentication_enabled_for_web,
       :password_authentication_enabled_for_git,
       :performance_bar_allowed_group_path,
@@ -436,6 +453,9 @@ module ApplicationSettingsHelper
       :throttle_authenticated_api_enabled,
       :throttle_authenticated_api_period_in_seconds,
       :throttle_authenticated_api_requests_per_period,
+      :throttle_authenticated_git_http_enabled,
+      :throttle_authenticated_git_http_period_in_seconds,
+      :throttle_authenticated_git_http_requests_per_period,
       :throttle_authenticated_git_lfs_enabled,
       :throttle_authenticated_git_lfs_period_in_seconds,
       :throttle_authenticated_git_lfs_requests_per_period,
@@ -482,6 +502,7 @@ module ApplicationSettingsHelper
       :unique_ips_limit_per_user,
       :unique_ips_limit_time_window,
       :usage_ping_enabled,
+      :usage_ping_generation_enabled,
       :usage_ping_features_enabled,
       :use_clickhouse_for_analytics,
       :user_default_external,
@@ -557,6 +578,7 @@ module ApplicationSettingsHelper
       :can_create_organization,
       :bulk_import_concurrent_pipeline_batch_limit,
       :concurrent_relation_batch_export_limit,
+      :relation_export_batch_size,
       :bulk_import_enabled,
       :bulk_import_max_download_file_size,
       :silent_admin_exports_enabled,
@@ -608,15 +630,18 @@ module ApplicationSettingsHelper
       :global_search_issues_enabled,
       :global_search_merge_requests_enabled,
       :global_search_block_anonymous_searches_enabled,
+      :enable_language_server_restrictions,
+      :minimum_language_server_version,
       :vscode_extension_marketplace,
       :vscode_extension_marketplace_enabled,
       :reindexing_minimum_index_size,
       :reindexing_minimum_relative_bloat_size,
       :anonymous_searches_allowed,
-      :git_push_pipeline_limit
+      :git_push_pipeline_limit,
+      :delay_user_account_self_deletion,
+      :resource_usage_limits
     ].tap do |settings|
       unless Gitlab.com?
-        settings << :resource_usage_limits
         settings << :deactivate_dormant_users
         settings << :deactivate_dormant_users_period
         settings << :nuget_skip_metadata_url_validation
@@ -696,7 +721,7 @@ module ApplicationSettingsHelper
       minimum_password_length_min: ApplicationSetting::DEFAULT_MINIMUM_PASSWORD_LENGTH,
       minimum_password_length_max: Devise.password_length.max,
       minimum_password_length_help_link:
-        'https://about.gitlab.com/handbook/security/#gitlab-password-policy-guidelines',
+        promo_url(path: '/handbook/security/', anchor: 'gitlab-password-policy-guidelines'),
       domain_allowlist_raw: @application_setting.domain_allowlist_raw,
       new_user_signups_cap: @application_setting[:new_user_signups_cap].to_s,
       domain_denylist_enabled: @application_setting[:domain_denylist_enabled].to_s,
@@ -712,9 +737,6 @@ module ApplicationSettingsHelper
   end
 
   def vscode_extension_marketplace_settings_view
-    # NOTE: This is intentionally not scoped to a specific actor since it affects instance-level settings.
-    return unless Feature.enabled?(:vscode_extension_marketplace_settings, nil)
-
     presets = ::WebIde::ExtensionMarketplacePreset.all.map do |preset|
       preset.to_h.deep_transform_keys { |key| key.to_s.camelize(:lower) }
     end
@@ -739,6 +761,11 @@ module ApplicationSettingsHelper
       deletion_adjourned_period: @application_setting[:deletion_adjourned_period]
     }
   end
+
+  # Overridden in EE
+  def custom_admin_roles_available?
+    false
+  end
 end
 
 ApplicationSettingsHelper.prepend_mod_with('ApplicationSettingsHelper')
