@@ -45,10 +45,8 @@ module DiffHelper
     options
   end
 
-  def rapid_diffs?
-    return false unless defined? current_user
-
-    ::Feature.enabled?(:rapid_diffs, current_user, type: :wip)
+  def with_custom_diff_options
+    yield diff_options.dup
   end
 
   def diff_match_line(old_pos, new_pos, text: '', view: :inline, bottom: false)
@@ -67,21 +65,13 @@ module DiffHelper
       expand_data[:expand_prev_line] = true
     end
 
-    if rapid_diffs?
-      expand_button = content_tag(:button, '...', class: 'gl-bg-transparent gl-border-0 gl-p-0', data: { visible_when_loading: false, **expand_data })
-      spinner = render(Pajamas::SpinnerComponent.new(size: :sm, class: 'gl-hidden gl-text-align-right', data: { visible_when_loading: true }))
-      expand_html = content_tag(:div, [expand_button, spinner].join.html_safe, data: { expand_wrapper: true })
-    else
-      expand_html = '...'
-    end
-
     if old_pos
-      html << content_tag(:td, expand_html, class: [*line_num_class, 'old_line'], data: { linenumber: old_pos })
+      html << content_tag(:td, '...', class: [*line_num_class, 'old_line'], data: { linenumber: old_pos })
       html << content_tag(:td, text, class: [*content_line_class, 'left-side']) if view == :parallel
     end
 
     if new_pos
-      html << content_tag(:td, expand_html, class: [*line_num_class, 'new_line'], data: { linenumber: new_pos })
+      html << content_tag(:td, '...', class: [*line_num_class, 'new_line'], data: { linenumber: new_pos })
       html << content_tag(:td, text, class: [*content_line_class, ('right-side' if view == :parallel)])
     end
 
@@ -157,20 +147,28 @@ module DiffHelper
     ].join(' ').html_safe
   end
 
-  def submodule_diff_compare_link(diff_file)
+  def submodule_diff_compare_data(diff_file)
     compare_url = submodule_links(diff_file.blob, diff_file.content_sha, diff_file.repository, diff_file)&.compare
-    return '' unless compare_url
+    return unless compare_url
 
-    link_text = [
-      _('Compare'),
-      ' ',
-      content_tag(:span, Commit.truncate_sha(diff_file.old_blob.id), class: 'commit-sha'),
-      '...',
-      content_tag(:span, Commit.truncate_sha(diff_file.blob.id), class: 'commit-sha')
-    ].join('').html_safe
+    title = safe_format(
+      _('Compare %{old_commit} to %{new_commit}'),
+      old_commit: content_tag(:span, Commit.truncate_sha(diff_file.old_blob.id), class: 'commit-sha'),
+      new_commit: content_tag(:span, Commit.truncate_sha(diff_file.blob.id), class: 'commit-sha')
+    )
 
-    tooltip = _('Compare submodule commit revisions')
-    link_button_to link_text, compare_url, class: 'has-tooltip submodule-compare', title: tooltip
+    {
+      title: title,
+      href: compare_url,
+      tooltip: _('Compare submodule commit revisions')
+    }
+  end
+
+  def submodule_diff_compare_link(diff_file)
+    data = submodule_diff_compare_data(diff_file)
+    return '' unless data
+
+    link_button_to data[:title], data[:href], class: 'has-tooltip submodule-compare', title: data[:tooltip]
   end
 
   def diff_file_blob_raw_url(diff_file, only_path: false)
@@ -301,6 +299,16 @@ module DiffHelper
     hide_whitespace? ? safe_params.except(:w) : safe_params.merge(w: 1)
   end
 
+  def file_heading_id(diff_file)
+    "#{diff_file.file_hash[0..8]}-heading"
+  end
+
+  def hide_whitespace?
+    return params[:w] == '1' if params.key?(:w)
+
+    current_user.nil? || !current_user.show_whitespace_in_diffs
+  end
+
   private
 
   def cached_conflicts_with_types
@@ -346,12 +354,6 @@ module DiffHelper
     toggle_whitespace_link(url, options)
   end
 
-  def hide_whitespace?
-    return params[:w] == '1' if params.key?(:w)
-
-    current_user.nil? || !current_user.show_whitespace_in_diffs
-  end
-
   def toggle_whitespace_link(url, options)
     toggle_text = hide_whitespace? ? s_('Diffs|Show whitespace changes') : s_('Diffs|Hide whitespace changes')
     link_button_to toggle_text, url, class: options[:class]
