@@ -17,6 +17,8 @@ module GitlabRoutingHelper
   include ::Routing::WikiHelper
   include ::Routing::GraphqlHelper
   include ::Routing::PseudonymizationHelper
+  include ::Routing::PackagesHelper
+  include ::Routing::OrganizationsHelper
   included do
     Gitlab::Routing.includes_helpers(self)
   end
