@@ -115,11 +115,12 @@ module ProjectsHelper
     push_to_schema_breadcrumb(simple_sanitize(project.name), project_path(project), project.try(:avatar_url))
   end
 
-  def remove_project_message(project)
-    _(
-      "You are going to delete %{project_full_name}. Deleted projects " \
-        "CANNOT be restored! Are you ABSOLUTELY sure?"
-    ) % { project_full_name: project.full_name }
+  def remove_project_message
+    format(
+      _("Deleting a project places it into a read-only state until %{date}, " \
+        "at which point the project will be permanently deleted. Are you ABSOLUTELY sure?"),
+      date: permanent_deletion_date_formatted(Date.current)
+    )
   end
 
   def link_to_namespace_change_doc
@@ -291,13 +292,13 @@ module ProjectsHelper
   def show_auto_devops_implicitly_enabled_banner?(project, user)
     return false unless user_can_see_auto_devops_implicitly_enabled_banner?(project, user)
 
-    cookies["hide_auto_devops_implicitly_enabled_banner_#{project.id}".to_sym].blank?
+    cookies[:"hide_auto_devops_implicitly_enabled_banner_#{project.id}"].blank?
   end
 
   def show_mobile_devops_project_promo?(project)
     return false unless (project.project_setting.target_platforms & ::ProjectSetting::ALLOWED_TARGET_PLATFORMS).any?
 
-    cookies["hide_mobile_devops_promo_#{project.id}".to_sym].blank?
+    cookies[:"hide_mobile_devops_promo_#{project.id}"].blank?
   end
 
   def no_password_message
@@ -344,16 +345,6 @@ module ProjectsHelper
     end
   end
 
-  def show_projects?(projects, params)
-    !!(
-      params[:personal] ||
-      params[:name] ||
-      params[:language] ||
-      params[:archived] == 'only' ||
-      any_projects?(projects)
-    )
-  end
-
   def push_to_create_project_command(user = current_user)
     repository_url =
       if Gitlab::CurrentSettings.current_application_settings.enabled_git_access_protocol == 'http'
@@ -408,15 +399,11 @@ module ProjectsHelper
                       .external_authorization_service_default_label
 
     s_(
-      "ExternalAuthorizationService|When no classification label is set the "\
+      "ExternalAuthorizationService|When no classification label is set the " \
         "default label `%{default_label}` will be used."
     ) % { default_label: default_label }
   end
 
-  def can_admin_project_member?(project)
-    Ability.allowed?(current_user, :admin_project_member, project) && !membership_locked?
-  end
-
   def project_can_be_shared?
     !membership_locked? || @project.allowed_to_share_with_group?
   end
@@ -444,6 +431,10 @@ module ProjectsHelper
   def show_lfs_misconfiguration_banner?(project)
     return false unless project.repository && project.lfs_enabled?
 
+    if current_user&.dismissed_callout_for_project?(feature_name: :lfs_misconfiguration_banner, project: project)
+      return false
+    end
+
     Rails.cache.fetch("show_lfs_misconfiguration_banner_#{project.id}", expires_in: 5.minutes) do
       project.lfs_objects_projects.project_repository_type.any? && !project.repository.has_gitattributes?
     end
@@ -511,7 +502,7 @@ module ProjectsHelper
     return unless current_user
     return if project.empty_repo?
 
-    if current_user.already_forked?(project) && !current_user.has_forkable_groups?
+    if current_user.already_forked?(project) && !current_user.has_groups_allowing_project_creation?
       user_fork_url = namespace_project_path(current_user, current_user.fork_of(project))
     end
 
@@ -568,7 +559,7 @@ module ProjectsHelper
       cicd_catalog_path: cicd_catalog_path,
       is_project_archived: project.archived.to_s,
       is_project_empty: project.empty_repo?.to_s,
-      is_project_marked_for_deletion: project.marked_for_deletion?.to_s,
+      is_project_marked_for_deletion: project.self_deletion_scheduled?.to_s,
       project_avatar: project.avatar_url,
       project_name: project.name,
       project_id: project.id,
@@ -588,13 +579,7 @@ module ProjectsHelper
   def archiving_available?(project)
     return false unless project
 
-    project.persisted? && !project.marked_for_deletion? && can?(current_user, :archive_project, project)
-  end
-
-  def show_archived_project_banner?(project)
-    return false unless project
-
-    project.persisted? && project.archived?
+    project.persisted? && !project.self_deletion_scheduled? && can?(current_user, :archive_project, project)
   end
 
   def show_inactive_project_deletion_banner?(project)
@@ -605,7 +590,7 @@ module ProjectsHelper
   end
 
   def inactive_project_deletion_date(project)
-    Gitlab::InactiveProjectsDeletionWarningTracker.new(project.id).scheduled_deletion_date
+    Gitlab::DormantProjectsDeletionWarningTracker.new(project.id).scheduled_deletion_date
   end
 
   def show_clusters_alert?(project)
@@ -644,14 +629,6 @@ module ProjectsHelper
     localized_access_names[access] || Gitlab::Access.human_access(access)
   end
 
-  def project_delete_delayed_button_data(project, button_text = nil)
-    project_delete_button_shared_data(project, button_text).merge({
-      restore_help_path: help_page_path('user/project/working_with_projects.md', anchor: 'restore-a-project'),
-      delayed_deletion_date: permanent_deletion_date_formatted(Date.current),
-      form_path: project_path(project)
-    })
-  end
-
   def badge_count(number)
     format_cached_count(1000, number)
   end
@@ -748,46 +725,6 @@ module ProjectsHelper
     dashboard_projects_landing_paths.include?(request.path) && !current_user.authorized_projects.exists?
   end
 
-  def scheduled_for_deletion?(project)
-    project.marked_for_deletion_at.present?
-  end
-
-  def delete_delayed_message(project)
-    date = permanent_deletion_date_formatted(Date.current)
-
-    if project.delayed_deletion_ready?
-      message = _("This action will place this project, including all its resources, in a pending deletion state " \
-        "for %{deletion_adjourned_period} days, and delete it permanently on %{date}.")
-      ERB::Util.html_escape(message) % delete_message_data(project).merge(date: tag.strong(date),
-        deletion_adjourned_period: project.deletion_adjourned_period)
-    else
-      delete_permanently_message
-    end
-  end
-
-  def delete_immediately_message(project)
-    return delete_permanently_message unless project.adjourned_deletion?
-    return delete_delayed_message(project) unless project.marked_for_deletion_on
-
-    date = permanent_deletion_date_formatted(project.marked_for_deletion_on)
-
-    message = _('This project is scheduled for deletion on %{date}. ' \
-      'This action will permanently delete this project, ' \
-      'including all its resources, %{strongOpen}immediately%{strongClose}. This action cannot be undone.')
-
-    ERB::Util.html_escape(message) % delete_message_data(project).merge(date: tag.strong(date))
-  end
-
-  def delete_permanently_message
-    _('This action will permanently delete this project, including all its resources.')
-  end
-
-  def project_delete_immediately_button_data(project, button_text = nil)
-    project_delete_button_shared_data(project, button_text).merge({
-      form_path: project_path(project, permanently_delete: true)
-    })
-  end
-
   def project_pages_domain_choices
     pages_url = build_pages_url(@project)
     blank_option = [[s_('GitLabPages|Don’t enforce a primary domain'), '']]
@@ -800,36 +737,33 @@ module ProjectsHelper
     )
   end
 
+  def project_archive_settings_app_data(project)
+    {
+      resource_type: 'project',
+      resource_id: project.id,
+      resource_path: project_path(project),
+      help_path: help_page_path('user/project/working_with_projects.md', anchor: 'archive-a-project')
+    }
+  end
+
+  def project_unarchive_settings_app_data(project)
+    {
+      resource_type: 'project',
+      resource_id: project.id,
+      resource_path: project_path(project),
+      ancestors_archived: project.ancestors_archived?.to_s,
+      help_path: help_page_path('user/project/working_with_projects.md', anchor: 'unarchive-a-project')
+    }
+  end
+
+  def show_archived_badge?(project)
+    return true if project.archived?
+
+    Feature.enabled?(:archive_group, project.root_ancestor) && project.ancestors_archived?
+  end
+
   private
 
-  def delete_message_data(project)
-    {
-      project_path_with_namespace: project.path_with_namespace,
-      project: project.path,
-      strongOpen: '<strong>'.html_safe,
-      strongClose: '</strong>'.html_safe,
-      codeOpen: '<code>'.html_safe,
-      codeClose: '</code>'.html_safe
-    }
-  end
-
-  def project_delete_button_shared_data(project, button_text = nil)
-    merge_requests_count = Projects::AllMergeRequestsCountService.new(project).count
-    issues_count = Projects::AllIssuesCountService.new(project).count
-    forks_count = Projects::ForksCountService.new(project).count
-
-    {
-      confirm_phrase: delete_confirm_phrase(project),
-      name_with_namespace: project.name_with_namespace,
-      is_fork: project.forked? ? 'true' : 'false',
-      issues_count: number_with_delimiter(issues_count),
-      merge_requests_count: number_with_delimiter(merge_requests_count),
-      forks_count: number_with_delimiter(forks_count),
-      stars_count: number_with_delimiter(project.star_count),
-      button_text: button_text.presence || _('Delete project')
-    }
-  end
-
   def can_admin_project_clusters?(project)
     project.clusters.any? && can?(current_user, :admin_cluster, project)
   end
@@ -940,6 +874,8 @@ module ProjectsHelper
   end
 
   def current_ref
+    return current_branch if @repository.try(:branch_exists?, current_branch)
+
     @ref || @repository.try(:root_ref)
   end
 
@@ -1077,20 +1013,6 @@ module ProjectsHelper
   end
 
   def project_permissions_data(project, target_form_id = nil)
-    data = visibility_confirm_modal_data(project, target_form_id)
-    cascading_settings_data = project_cascading_namespace_settings_tooltip_data(
-      :duo_features_enabled,
-      project,
-      method(:edit_group_path)
-    ).to_json
-    data.merge!(
-      {
-        cascading_settings_data: cascading_settings_data
-      }
-    )
-  end
-
-  def visibility_confirm_modal_data(project, target_form_id = nil)
     {
       target_form_id: target_form_id,
       button_testid: 'reduce-project-visibility-button',
@@ -1103,6 +1025,21 @@ module ProjectsHelper
     }
   end
 
+  def gitlab_duo_settings_data(project)
+    {
+      duo_availability_cascading_settings: project_cascading_namespace_settings_tooltip_data(
+        :duo_features_enabled,
+        project,
+        method(:edit_group_path)
+      ),
+      duo_remote_flows_cascading_settings: project_cascading_namespace_settings_tooltip_data(
+        :duo_remote_flows_enabled,
+        project,
+        method(:edit_group_path)
+      )
+    }
+  end
+
   def delete_inactive_projects?
     strong_memoize(:delete_inactive_projects_setting) do
       ::Gitlab::CurrentSettings.delete_inactive_projects?
