@@ -112,6 +112,10 @@ class NotifyPreview < ActionMailer::Preview
     Notify.access_token_about_to_expire_email(user, ['%w', '%w']).message
   end
 
+  def deploy_token_about_to_expire_email
+    Notify.deploy_token_about_to_expire_email(user, 'token_name', project).message
+  end
+
   def ssh_key_expired_email
     fingerprints = []
     Notify.ssh_key_expired_email(user, fingerprints).message
@@ -249,6 +253,26 @@ class NotifyPreview < ActionMailer::Preview
     Notify.pipeline_fixed_email(pipeline, pipeline.user.try(:email))
   end
 
+  def pipeline_variables_migration_complete_email
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 5, skipped_count: 3 }).message
+  end
+
+  def pipeline_variables_migration_complete_email_all_updated
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 10, skipped_count: 0 }).message
+  end
+
+  def pipeline_variables_migration_complete_email_single_project
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 1, skipped_count: 0 }).message
+  end
+
+  def pipeline_variables_migration_complete_email_single_skipped
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 2, skipped_count: 1 }).message
+  end
+
+  def pipeline_schedule_owner_unavailable
+    Notify.pipeline_schedule_owner_unavailable_email(pipeline_schedule, user)
+  end
+
   def autodevops_disabled_email
     Notify.autodevops_disabled_email(pipeline, user.email).message
   end
@@ -452,6 +476,12 @@ class NotifyPreview < ActionMailer::Preview
     Notify.import_source_user_rejected(source_user.id)
   end
 
+  def import_source_user_complete
+    source_user = Import::SourceUser.last
+
+    Notify.import_source_user_complete(source_user.id)
+  end
+
   def repository_rewrite_history_success_email
     Notify.repository_rewrite_history_success_email(project, user)
   end
@@ -554,6 +584,10 @@ class NotifyPreview < ActionMailer::Preview
     @pipeline = Ci::Pipeline.last
   end
 
+  def pipeline_schedule
+    @pipeline_schedule ||= Ci::PipelineSchedule.last
+  end
+
   def remote_mirror
     @remote_mirror ||= RemoteMirror.last
   end
