@@ -7,33 +7,15 @@ class ApplicationSetting < ApplicationRecord
   include ChronicDurationAttribute
   include Sanitizable
   include Gitlab::EncryptedAttribute
-  include SafelyChangeColumnDefault
+  include IgnorableColumns
 
-  columns_changing_default :enforce_ci_inbound_job_token_scope_enabled
+  ignore_column :model_prompt_cache_enabled, remove_with: '18.5', remove_after: '2025-10-05'
+  ignore_column :lock_model_prompt_cache_enabled, remove_with: '18.5', remove_after: '2025-10-05'
 
-  ignore_column :pre_receive_secret_detection_enabled, remove_with: '17.9', remove_after: '2025-02-15'
-
-  ignore_columns %i[
-    security_policy_scheduled_scans_max_concurrency
-  ], remove_with: '17.11', remove_after: '2025-04-17'
   INSTANCE_REVIEW_MIN_USERS = 50
   GRAFANA_URL_ERROR_MESSAGE = 'Please check your Grafana URL setting in ' \
     'Admin area > Settings > Metrics and profiling > Metrics - Grafana'
 
-  ignore_columns %i[
-    package_registry_allow_anyone_to_pull_option
-    package_registry_cleanup_policies_worker_capacity
-    packages_cleanup_package_file_worker_capacity
-    npm_package_requests_forwarding
-    lock_npm_package_requests_forwarding
-    maven_package_requests_forwarding
-    lock_maven_package_requests_forwarding
-    pypi_package_requests_forwarding
-    lock_pypi_package_requests_forwarding
-  ], remove_with: '18.1', remove_after: '2025-05-20'
-
-  ignore_column :duo_nano_features_enabled, remove_with: '18.1', remove_after: '2025-06-19'
-
   KROKI_URL_ERROR_MESSAGE = 'Please check your Kroki URL setting in ' \
     'Admin area > Settings > General > Kroki'
 
@@ -54,10 +36,11 @@ class ApplicationSetting < ApplicationRecord
 
   USERS_UNCONFIRMED_SECONDARY_EMAILS_DELETE_AFTER_DAYS = 3
 
-  INACTIVE_RESOURCE_ACCESS_TOKENS_DELETE_AFTER_DAYS = 30
-
   DEFAULT_HELM_MAX_PACKAGES_COUNT = 1000
 
+  DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT = 3600
+  DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD = 3600
+
   enum :whats_new_variant, { all_tiers: 0, current_tier: 1, disabled: 2 }, prefix: true
   enum :email_confirmation_setting, { off: 0, soft: 1, hard: 2 }, prefix: true
 
@@ -70,7 +53,7 @@ class ApplicationSetting < ApplicationRecord
   add_authentication_token_field :error_tracking_access_token, encrypted: :required # rubocop:todo -- https://gitlab.com/gitlab-org/gitlab/-/issues/439292
 
   belongs_to :push_rule
-  belongs_to :web_ide_oauth_application, class_name: 'Doorkeeper::Application'
+  belongs_to :web_ide_oauth_application, class_name: 'Authn::OauthApplication'
 
   alias_attribute :housekeeping_optimize_repository_period, :housekeeping_incremental_repack_period
 
@@ -262,6 +245,9 @@ class ApplicationSetting < ApplicationRecord
   validates :container_expiration_policies_enable_historic_entries,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
 
+  validates :pipeline_variables_default_allowed,
+    inclusion: { in: [true, false], message: N_('must be a boolean value') }
+
   validate :check_repository_storages_weighted
 
   validates :auto_devops_domain,
@@ -344,10 +330,10 @@ class ApplicationSetting < ApplicationRecord
     allow_blank: true
 
   jsonb_accessor :token_prefixes,
-    instance_token_prefix: [:string, { default: 'gl' }]
+    instance_token_prefix: [:string, { default: '' }]
 
   validates :instance_token_prefix,
-    format: { with: %r{\A[a-zA-Z0-9-]+\z} },
+    format: { with: %r{\A[a-zA-Z0-9]+\z} },
     length: { maximum: 20, message: N_('is too long (maximum is %{count} characters)') },
     allow_blank: true
 
@@ -462,7 +448,12 @@ class ApplicationSetting < ApplicationRecord
 
   validates_each :import_sources, on: :update do |record, attr, value|
     value&.each do |source|
-      unless Gitlab::ImportSources.options.value?(source)
+      # Temporary allow "gitlab_custom_project_template" to avoid validation errors
+      # "gitlab_custom_project_template" can be excluded after incorrect values are removed from the database
+      # Issue: https://gitlab.com/gitlab-org/gitlab/-/issues/550410
+      allowed_import_sources = Gitlab::ImportSources.values - ['gitlab_built_in_project_template']
+
+      unless allowed_import_sources.include?(source)
         record.errors.add(attr, format(_("'%{source}' is not a import source"), source: source))
       end
     end
@@ -529,6 +520,7 @@ class ApplicationSetting < ApplicationRecord
     if: ->(setting) { setting.external_auth_client_cert.present? }
 
   jsonb_accessor :ci_cd_settings,
+    pipeline_variables_default_allowed: [:boolean, { default: true }],
     ci_job_live_trace_enabled: [:boolean, { default: false }],
     ci_partitions_size_limit: [::Gitlab::Database::Type::JsonbInteger.new, { default: 100.gigabytes }],
     ci_delete_pipelines_in_seconds_limit: [:integer, { default: ChronicDuration.parse('1 year') }],
@@ -605,6 +597,7 @@ class ApplicationSetting < ApplicationRecord
       :max_yaml_size_bytes,
       :namespace_aggregation_schedule_lease_duration_in_seconds,
       :project_jobs_api_rate_limit,
+      :relation_export_batch_size,
       :session_expire_delay,
       :snippet_size_limit,
       :throttle_authenticated_api_period_in_seconds,
@@ -613,6 +606,8 @@ class ApplicationSetting < ApplicationRecord
       :throttle_authenticated_deprecated_api_requests_per_period,
       :throttle_authenticated_files_api_period_in_seconds,
       :throttle_authenticated_files_api_requests_per_period,
+      :throttle_authenticated_git_http_period_in_seconds,
+      :throttle_authenticated_git_http_requests_per_period,
       :throttle_authenticated_git_lfs_period_in_seconds,
       :throttle_authenticated_git_lfs_requests_per_period,
       :throttle_authenticated_packages_api_period_in_seconds,
@@ -660,6 +655,8 @@ class ApplicationSetting < ApplicationRecord
       :max_export_size,
       :max_github_response_size_limit,
       :max_github_response_json_value_count,
+      :max_http_decompressed_size,
+      :max_http_response_size_limit,
       :max_import_remote_file_size,
       :max_import_size,
       :max_pages_custom_domains_per_project,
@@ -698,6 +695,11 @@ class ApplicationSetting < ApplicationRecord
   attribute :resource_usage_limits, ::Gitlab::Database::Type::IndifferentJsonb.new, default: -> { {} }
   validates :resource_usage_limits, json_schema: { filename: 'resource_usage_limits' }
 
+  jsonb_accessor :resource_access_tokens_settings,
+    inactive_resource_access_tokens_delete_after_days: [:integer, { default: 30 }]
+
+  validates :resource_access_tokens_settings, json_schema: { filename: 'resource_access_tokens_settings' }
+
   jsonb_accessor :group_settings,
     top_level_group_creation_enabled: [:boolean, { default: true }],
     disable_invite_members: [:boolean, { default: false }]
@@ -711,6 +713,8 @@ class ApplicationSetting < ApplicationRecord
   validates :clickhouse, json_schema: { filename: "application_setting_clickhouse" }
 
   jsonb_accessor :response_limits,
+    max_http_response_size_limit: [:integer, { default: 100 }],
+    max_http_decompressed_size: [:integer, { default: 100 }],
     max_github_response_size_limit: [:integer, { default: 8 }],
     max_github_response_json_value_count: [:integer, { default: 250_000 }]
 
@@ -726,7 +730,8 @@ class ApplicationSetting < ApplicationRecord
   jsonb_accessor :importers,
     silent_admin_exports_enabled: [:boolean, { default: false }],
     allow_contribution_mapping_to_admins: [:boolean, { default: false }],
-    allow_bypass_placeholder_confirmation: [:boolean, { default: false }]
+    allow_bypass_placeholder_confirmation: [:boolean, { default: false }],
+    relation_export_batch_size: [:integer, { default: 50 }]
 
   jsonb_accessor :sign_in_restrictions,
     disable_password_authentication_for_users_with_sso_identities: [:boolean, { default: false }],
@@ -857,7 +862,8 @@ class ApplicationSetting < ApplicationRecord
       :pypi_package_requests_forwarding,
       :lock_pypi_package_requests_forwarding,
       :maven_package_requests_forwarding,
-      :lock_maven_package_requests_forwarding
+      :lock_maven_package_requests_forwarding,
+      :pages_unique_domain_default_enabled
     )
   end
 
@@ -868,11 +874,16 @@ class ApplicationSetting < ApplicationRecord
   validates :asciidoc_max_includes,
     numericality: { only_integer: true, greater_than_or_equal_to: 0, less_than_or_equal_to: 64 }
 
-  jsonb_accessor :pages, pages_extra_deployments_default_expiry_seconds: [:integer, { default: 86400 }]
+  jsonb_accessor :pages,
+    pages_extra_deployments_default_expiry_seconds: [:integer, { default: 86400 }],
+    pages_unique_domain_default_enabled: [:boolean, { default: true }]
+
   validates :pages, json_schema: { filename: "application_setting_pages" }
 
   jsonb_accessor :anti_abuse_settings,
-    enforce_email_subaddress_restrictions: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }]
+    enforce_email_subaddress_restrictions: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }],
+    require_email_verification_on_account_locked: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }],
+    delay_user_account_self_deletion: [::Gitlab::Database::Type::JsonbBoolean.new, { default: false }]
 
   validates :anti_abuse_settings, json_schema: { filename: "anti_abuse_settings", detail_errors: true }
 
@@ -880,7 +891,7 @@ class ApplicationSetting < ApplicationRecord
     allow_nil: false,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
 
-  attr_encrypted :asset_proxy_secret_key,
+  migrate_to_encrypts :asset_proxy_secret_key,
     mode: :per_attribute_iv,
     key: :db_key_base_truncated,
     algorithm: 'aes-256-cbc',
@@ -966,11 +977,21 @@ class ApplicationSetting < ApplicationRecord
     allow_nil: false,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
 
+  jsonb_accessor :default_profile_preferences,
+    default_dark_syntax_highlighting_theme: [:integer, { default: 2 }]
+
+  validates :default_profile_preferences, json_schema: { filename: "application_setting_default_profile_preferences" }
+
   validates :default_syntax_highlighting_theme,
     allow_nil: false,
     numericality: { only_integer: true, greater_than: 0 },
     inclusion: { in: Gitlab::ColorSchemes.valid_ids, message: N_('must be a valid syntax highlighting theme ID') }
 
+  validates :default_dark_syntax_highlighting_theme,
+    allow_nil: false,
+    numericality: { only_integer: true, greater_than: 0 },
+    inclusion: { in: Gitlab::ColorSchemes.valid_ids, message: N_('must be a valid syntax highlighting theme ID') }
+
   validates :gitlab_dedicated_instance,
     allow_nil: false,
     inclusion: { in: [true, false], message: N_('must be a boolean value') }
@@ -993,6 +1014,13 @@ class ApplicationSetting < ApplicationRecord
   jsonb_accessor :vscode_extension_marketplace,
     vscode_extension_marketplace_enabled: [:boolean, { default: false, store_key: :enabled }]
 
+  jsonb_accessor :editor_extensions,
+    enable_language_server_restrictions: [:boolean, { default: false }],
+    minimum_language_server_version: [:string, { default: '0.1.0' }]
+
+  validates :editor_extensions,
+    json_schema: { filename: 'application_setting_editor_extensions', detail_errors: true }
+
   before_validation :ensure_uuid!
   before_validation :coerce_repository_storages_weighted, if: :repository_storages_weighted_changed?
   before_validation :normalize_default_branch_name
@@ -1128,6 +1156,11 @@ class ApplicationSetting < ApplicationRecord
       group_archive_unarchive_api_limit: [:integer, { default: 60 }],
       project_invited_groups_api_limit: [:integer, { default: 60 }],
       projects_api_limit: [:integer, { default: 2000 }],
+      throttle_authenticated_git_http_enabled: [:boolean, { default: false }],
+      throttle_authenticated_git_http_requests_per_period:
+        [:integer, { default: DEFAULT_AUTHENTICATED_GIT_HTTP_LIMIT }],
+      throttle_authenticated_git_http_period_in_seconds:
+        [:integer, { default: DEFAULT_AUTHENTICATED_GIT_HTTP_PERIOD }],
       user_contributed_projects_api_limit: [:integer, { default: 100 }],
       user_projects_api_limit: [:integer, { default: 300 }],
       user_starred_projects_api_limit: [:integer, { default: 100 }],
@@ -1185,17 +1218,11 @@ class ApplicationSetting < ApplicationRecord
   end
 
   def allow_user_remember_me?
-    return false if session_expire_from_init_enabled?
+    return false if session_expire_from_init?
 
     remember_me_enabled?
   end
 
-  # check the model first, as this will be false on most instances
-  # only check Redis / FF if setting is enabled
-  def session_expire_from_init_enabled?
-    session_expire_from_init? && Feature.enabled?(:session_expire_from_init, :instance)
-  end
-
   private
 
   def parsed_grafana_url
@@ -1234,7 +1261,7 @@ class ApplicationSetting < ApplicationRecord
   end
 
   def reset_deletion_warning_redis_key
-    Gitlab::InactiveProjectsDeletionWarningTracker.reset_all
+    Gitlab::DormantProjectsDeletionWarningTracker.reset_all
   end
 
   def should_prevent_visibility_restriction?
