@@ -15,13 +15,15 @@ module Ci
         .lock('FOR UPDATE SKIP LOCKED')
     end
 
+    validates :project_id, presence: true, on: :create
+
     def self.bulk_import(artifacts, pick_up_at = nil)
       attributes = artifacts.each.with_object([]) do |artifact, accumulator|
         record = artifact.to_deleted_object_attrs(pick_up_at)
         accumulator << record if record[:store_dir] && record[:file]
       end
 
-      self.insert_all(attributes) if attributes.any?
+      insert_all(attributes) if attributes.any?
     end
 
     def delete_file_from_storage
