@@ -10,10 +10,14 @@ module Ci
     include Artifactable
     include Lockable
     include FileStoreMounter
+    include ObjectStorable
     include EachBatch
     include Gitlab::Utils::StrongMemoize
 
+    STORE_COLUMN = :file_store
     PLAN_LIMIT_PREFIX = 'ci_max_artifact_size_'
+    MAX_EXPOSED_AS_LENGTH = 100
+    EXPOSED_PATH_REGEX = /\A[^*]*\z/
 
     InvalidArtifactError = Class.new(StandardError)
 
@@ -24,7 +28,7 @@ module Ci
     partitionable scope: :job, partitioned: true
     query_constraints :id, :partition_id
 
-    enum :accessibility, { public: 0, private: 1, none: 2 }, suffix: true
+    enum :accessibility, { public: 0, private: 1, none: 2, maintainer: 3 }, suffix: true
 
     belongs_to :project
     belongs_to :job,
@@ -55,6 +59,8 @@ module Ci
     validates :job, presence: true
     validates :file_format, presence: true, unless: :trace?, on: :create
     validate :validate_file_format!, unless: :trace?, on: :create
+    validates :exposed_as, length: { maximum: MAX_EXPOSED_AS_LENGTH }
+    validate :validate_exposed_paths, if: -> { exposed_paths.present? }
 
     scope :not_expired, -> { where('expire_at IS NULL OR expire_at > ?', Time.current) }
     scope :for_sha, ->(sha, project_id) { joins(job: :pipeline).merge(Ci::Pipeline.for_sha(sha).for_project(project_id)) }
@@ -109,12 +115,6 @@ module Ci
     #                 This is the default value.
     enum :file_location, Enums::Ci::JobArtifact.file_location
 
-    def validate_file_format!
-      unless Enums::Ci::JobArtifact.type_and_format_pairs[self.file_type&.to_sym] == self.file_format&.to_sym
-        errors.add(:base, _('Invalid file format with specified file type'))
-      end
-    end
-
     def self.of_report_type(report_type)
       file_types = file_types_for_report(report_type)
 
@@ -163,6 +163,27 @@ module Ci
       service.update_statistics
     end
 
+    def self.archived_trace_exists_for?(job_id)
+      where(job_id: job_id).trace.take&.stored?
+    end
+
+    def self.max_artifact_size(type:, project:)
+      limit_name = "#{PLAN_LIMIT_PREFIX}#{type}"
+
+      max_size = project.actual_limits.limit_for(
+        limit_name,
+        alternate_limit: -> { project.closest_setting(:max_artifacts_size) }
+      )
+
+      max_size&.megabytes.to_i
+    end
+
+    def validate_file_format!
+      unless Enums::Ci::JobArtifact.type_and_format_pairs[self.file_type&.to_sym] == self.file_format&.to_sym
+        errors.add(:base, _('Invalid file format with specified file type'))
+      end
+    end
+
     def local_store?
       [nil, ::JobArtifactUploader::Store::LOCAL].include?(self.file_store)
     end
@@ -194,21 +215,6 @@ module Ci
       file&.file&.exists?
     end
 
-    def self.archived_trace_exists_for?(job_id)
-      where(job_id: job_id).trace.take&.stored?
-    end
-
-    def self.max_artifact_size(type:, project:)
-      limit_name = "#{PLAN_LIMIT_PREFIX}#{type}"
-
-      max_size = project.actual_limits.limit_for(
-        limit_name,
-        alternate_limit: -> { project.closest_setting(:max_artifacts_size) }
-      )
-
-      max_size&.megabytes.to_i
-    end
-
     def to_deleted_object_attrs(pick_up_at = nil)
       final_path_store_dir, final_path_filename = nil
       if file_final_path.present?
@@ -239,6 +245,10 @@ module Ci
       none_accessibility?
     end
 
+    def maintainer_access?
+      maintainer_accessibility?
+    end
+
     def each_blob(&blk)
       if junit? && artifact_report.nil?
         build_artifact_report(status: :validated, validation_error: nil, project_id: project_id)
@@ -293,6 +303,12 @@ module Ci
     def log_destroy
       Gitlab::Ci::Artifacts::Logger.log_deleted(self, __method__)
     end
+
+    def validate_exposed_paths
+      return if exposed_paths.is_a?(Array) && exposed_paths.all? { |path| path.match?(EXPOSED_PATH_REGEX) }
+
+      errors.add(:exposed_paths, 'must be an array of strings without `*`')
+    end
   end
 end
 
