@@ -197,7 +197,10 @@ module Ci
 
     # We only check jobs that are played by `Ci::PlayManualStageService`.
     def confirm_manual_job?
-      processables.manual.any? do |job|
+      manual_jobs = processables.manual
+      return false unless manual_jobs.exists?
+
+      manual_jobs.includes(:pipeline, :metadata, [deployment: [environment: :project]]).any? do |job|
         job.playable? && job.manual_confirmation_message
       end
     end
@@ -218,11 +221,14 @@ module Ci
     private
 
     def preload_metadata(statuses)
-      relations = [:metadata, :pipeline, { downstream_pipeline: [:user, { project: [:route, { namespace: :route }] }] }]
+      relations = [:metadata, :job_definition, :error_job_messages, :pipeline,
+        { downstream_pipeline: [:user, { project: [:route, { namespace: :route }] }] }]
 
-      Preloaders::CommitStatusPreloader.new(statuses).execute(relations)
+      ::Ci::Preloaders::CommitStatusPreloader.new(statuses).execute(relations)
 
       statuses
     end
   end
 end
+
+Ci::Stage.prepend_mod
