@@ -1,10 +1,13 @@
 # frozen_string_literal: true
 
 class JiraConnectInstallation < ApplicationRecord
+  include Gitlab::Routing
+  include Gitlab::EncryptedAttribute
+
   attr_encrypted :shared_secret,
-                 mode: :per_attribute_iv,
-                 algorithm: 'aes-256-gcm',
-                 key: Settings.attr_encrypted_db_key_base_32
+    mode: :per_attribute_iv,
+    algorithm: 'aes-256-gcm',
+    key: :db_key_base_32
 
   has_many :subscriptions, class_name: 'JiraConnectSubscription'
 
@@ -13,7 +16,7 @@ class JiraConnectInstallation < ApplicationRecord
   validates :base_url, presence: true, public_url: true
   validates :instance_url, public_url: true, allow_blank: true
 
-  scope :for_project, -> (project) {
+  scope :for_project, ->(project) {
     distinct
       .joins(:subscriptions)
       .where(jira_connect_subscriptions: {
@@ -29,7 +32,7 @@ class JiraConnectInstallation < ApplicationRecord
   end
 
   def oauth_authorization_url
-    return Gitlab.config.gitlab.url if instance_url.blank? || Feature.disabled?(:jira_connect_oauth_self_managed)
+    return Gitlab.config.gitlab.url if instance_url.blank?
 
     instance_url
   end
@@ -37,13 +40,25 @@ class JiraConnectInstallation < ApplicationRecord
   def audience_url
     return unless proxy?
 
-    Gitlab::Utils.append_path(instance_url, '/-/jira_connect')
+    Gitlab::Utils.append_path(instance_url, jira_connect_base_path)
   end
 
   def audience_installed_event_url
     return unless proxy?
 
-    Gitlab::Utils.append_path(instance_url, '/-/jira_connect/events/installed')
+    Gitlab::Utils.append_path(instance_url, jira_connect_events_installed_path)
+  end
+
+  def audience_uninstalled_event_url
+    return unless proxy?
+
+    Gitlab::Utils.append_path(instance_url, jira_connect_events_uninstalled_path)
+  end
+
+  def create_branch_url
+    return unless proxy?
+
+    Gitlab::Utils.append_path(instance_url, new_jira_connect_branch_path)
   end
 
   def proxy?
