@@ -6,6 +6,7 @@ module Users
 
     self.table_name = 'user_callouts'
 
+    # NOTE: to avoid false-positive dismissals, use new consecutive enum values for new callout IDs
     enum :feature_name, {
       gke_cluster_integration: 1,
       gcp_signup_offer: 2,
@@ -55,7 +56,7 @@ module Users
       user_reached_limit_free_plan_alert: 51, # EE-only
       submit_license_usage_data_banner: 52, # EE-only
       personal_project_limitations_banner: 53, # EE-only
-      mr_experience_survey: 54,
+      # 54 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/195384
       # 55 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/121920
       namespace_storage_limit_alert_warning_threshold: 56, # EE-only
       namespace_storage_limit_alert_alert_threshold: 57, # EE-only
@@ -81,7 +82,7 @@ module Users
       # 79 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/143862
       duo_chat_callout: 80, # EE-only
       # 81 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/146322
-      product_analytics_dashboard_feedback: 82, # EE-only
+      # 82 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/203697
       joining_a_project_alert: 83, # EE-only
       transition_to_jihu_callout: 84,
       # 85 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/169248
@@ -96,7 +97,7 @@ module Users
       openssl_callout: 94,
       # 95 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/170868
       new_mr_dashboard_banner: 96,
-      planner_role_callout: 97,
+      # 97 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/196130
       # EE-only
       pipl_compliance_alert: 98,
       new_merge_request_dashboard_welcome: 99,
@@ -106,9 +107,14 @@ module Users
       product_usage_data_collection_changes: 103,
       dora_dashboard_migration_group: 104,
       dora_dashboard_migration_project: 105,
-      enable_duo_banner_admin_duo_settings_page: 106, # EE-only
-      enable_duo_banner_admin_dashboard: 107, # EE-only
-      explore_duo_core_banner: 108 # EE-only
+      # 106 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/202983
+      # 107 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/202983
+      explore_duo_core_banner: 108, # EE-only
+      merge_request_dashboard_display_preferences_popover: 109,
+      vulnerability_archival: 110, # EE-only
+      duo_amazon_q_alert: 111, # EE-only
+      personal_homepage_preferences_banner: 112,
+      duo_agent_platform_requested: 113 # EE-only
     }
 
     validates :feature_name,
