@@ -318,11 +318,6 @@ class ProjectPolicy < BasePolicy
     Feature.enabled?(:allow_guest_plus_roles_to_pull_packages, @subject.root_ancestor)
   end
 
-  condition(:ancestor_scheduled_for_deletion, scope: :subject) do
-    !@subject.self_deletion_scheduled? && @subject.scheduled_for_deletion_in_hierarchy_chain?
-  end
-  condition(:parent_deletion_in_progress, scope: :subject) { @subject.parent.self_deletion_in_progress? }
-
   # `:read_project` may be prevented in EE, but `:read_project_for_iids` should
   # not.
   rule { guest | admin | organization_owner }.enable :read_project_for_iids
@@ -369,6 +364,10 @@ class ProjectPolicy < BasePolicy
     enable :set_warn_about_potentially_unwanted_characters
     enable :manage_owners
 
+    enable :create_group_link
+    enable :update_group_link
+    enable :delete_group_link
+
     enable :add_catalog_resource
 
     enable :destroy_pipeline
@@ -443,8 +442,6 @@ class ProjectPolicy < BasePolicy
 
   rule { guest & ~public_project }.enable :read_grafana
 
-  rule { ancestor_scheduled_for_deletion & ~parent_deletion_in_progress }.prevent :remove_project
-
   rule { can?(:reporter_access) }.policy do
     enable :admin_issue_board
     enable :read_code
