@@ -20,10 +20,16 @@ module Integrations
 
     expose :field, if: ->(_, _) { integration.try(:configurable_channels?) } do
       expose :name do |event|
-        integration.event_channel_name(event)
+        integration.class.event_channel_name(event)
       end
       expose :value do |event|
-        integration.event_channel_value(event)
+        value = integration.event_channel_value(event)
+        next Base::ChatNotification::SECRET_MASK if value.present? && integration.mask_configurable_channels?
+
+        value
+      end
+      expose :placeholder do |_event|
+        integration.default_channel_placeholder
       end
     end
 
