@@ -12,6 +12,20 @@ module Ci
 
     Result = Struct.new(:build, :build_json, :build_presented, :valid?)
 
+    class ResultFactory
+      def self.success(build, build_json, build_presented)
+        Result.new(build: build, build_json: build_json, build_presented: build_presented, valid?: true)
+      end
+
+      def self.conflict(valid:)
+        Result.new(build: nil, build_json: nil, build_presented: nil, valid?: valid)
+      end
+
+      def self.invalid
+        conflict(valid: false)
+      end
+    end
+
     ##
     # The queue depth limit number has been determined by observing 95
     # percentile of effective queue depth on gitlab.com. This is only likely to
@@ -42,7 +56,7 @@ module Ci
       if !replica_caught_up && !result.build
         metrics.increment_queue_operation(:queue_replication_lag)
 
-        ::Ci::RegisterJobService::Result.new(nil, nil, nil, false)
+        ResultFactory.invalid
       else
         result
       end
@@ -65,7 +79,7 @@ module Ci
       valid = true
       depth = 0
 
-      each_build(params) do |build|
+      each_build(params) do |build, queue_size|
         depth += 1
         @metrics.increment_queue_operation(:queue_iteration)
 
@@ -93,13 +107,12 @@ module Ci
         end
 
         result = @logger.instrument(:process_build) do
-          process_build(build, params)
+          process_build(build, params, queue_size: queue_size, queue_depth: depth)
         end
         next unless result
 
         if result.valid?
-          @metrics.register_success(result.build_presented)
-          @metrics.observe_queue_depth(:found, depth)
+          track_success(result, depth)
 
           return result # rubocop:disable Cop/AvoidReturnFromBlocks
         else
@@ -109,44 +122,23 @@ module Ci
         end
       end
 
-      @metrics.increment_queue_operation(:queue_conflict) unless valid
-      @metrics.observe_queue_depth(:conflict, depth) unless valid
-      @metrics.observe_queue_depth(:not_found, depth) if valid
-      @metrics.register_failure
+      track_conflict(depth, valid)
 
-      Result.new(nil, nil, nil, valid)
+      ResultFactory.conflict(valid: valid)
     end
 
     # rubocop: disable CodeReuse/ActiveRecord
     def each_build(params, &blk)
-      queue = ::Ci::Queue::BuildQueueService.new(runner)
-
-      builds = if runner.instance_type?
-                 queue.builds_for_shared_runner
-               elsif runner.group_type?
-                 queue.builds_for_group_runner
-               else
-                 queue.builds_for_project_runner
-               end
-
-      if runner.ref_protected?
-        builds = queue.builds_for_protected_runner(builds)
-      end
-
-      # pick builds that does not have other tags than runner's one
-      builds = queue.builds_matching_tag_ids(builds, runner.tags.ids)
-
-      # pick builds that have at least one tag
-      unless runner.run_untagged?
-        builds = queue.builds_with_any_tags(builds)
-      end
+      queue = Ci::Queue::BuildQueueService.new(runner)
+      builds = queue.build_candidates
 
       build_and_partition_ids = retrieve_queue(-> { queue.execute(builds) })
+      queue_size = build_and_partition_ids.size
 
-      @metrics.observe_queue_size(-> { build_and_partition_ids.size }, @runner.runner_type)
+      @metrics.observe_queue_size(-> { queue_size }, @runner.runner_type)
 
       build_and_partition_ids.each do |build_id, partition_id|
-        yield Ci::Build.find_by!(partition_id: partition_id, id: build_id)
+        yield Ci::Build.find_by!(partition_id: partition_id, id: build_id), queue_size
       end
     end
     # rubocop: enable CodeReuse/ActiveRecord
@@ -165,7 +157,7 @@ module Ci
       end
     end
 
-    def process_build(build, params)
+    def process_build(build, params, queue_size:, queue_depth:)
       return remove_from_queue!(build) unless build.pending?
 
       if runner_matched?(build)
@@ -183,7 +175,7 @@ module Ci
       # In case when 2 runners try to assign the same build, second runner will be declined
       # with StateMachines::InvalidTransition or StaleObjectError when doing run! or save method.
       if assign_runner_with_instrumentation!(build, params)
-        present_build_with_instrumentation!(build)
+        present_build_with_instrumentation!(build, queue_size: queue_size, queue_depth: queue_depth)
       end
     rescue ActiveRecord::StaleObjectError
       # We are looping to find another build that is not conflicting
@@ -197,11 +189,11 @@ module Ci
       # to make sure that this is properly handled by runner.
       @metrics.increment_queue_operation(:build_conflict_lock)
 
-      Result.new(nil, nil, nil, false)
+      ResultFactory.invalid
     rescue StateMachines::InvalidTransition
       @metrics.increment_queue_operation(:build_conflict_transition)
 
-      Result.new(nil, nil, nil, false)
+      ResultFactory.invalid
     rescue StandardError => ex
       @metrics.increment_queue_operation(:build_conflict_exception)
 
@@ -226,7 +218,7 @@ module Ci
       # `ci_pending_builds` table, we need to respond with 409 to retry
       # this operation.
       #
-      Result.new(nil, nil, nil, false) if ::Ci::UpdateBuildQueueService.new.remove!(build)
+      ResultFactory.invalid if ::Ci::UpdateBuildQueueService.new.remove!(build)
     end
 
     def runner_matched?(build)
@@ -235,17 +227,18 @@ module Ci
       end
     end
 
-    def present_build_with_instrumentation!(build)
+    def present_build_with_instrumentation!(build, queue_size:, queue_depth:)
       @logger.instrument(:process_build_present_build) do
-        present_build!(build)
+        present_build!(build, queue_size: queue_size, queue_depth: queue_depth)
       end
     end
 
     # Force variables evaluation to occur now
-    def present_build!(build)
+    def present_build!(build, queue_size:, queue_depth:)
       # We need to use the presenter here because Gitaly calls in the presenter
       # may fail, and we need to ensure the response has been generated.
       presented_build = ::Ci::BuildRunnerPresenter.new(build) # rubocop:disable CodeReuse/Presenter -- old code
+      presented_build.set_queue_metrics(size: queue_size, depth: queue_depth)
 
       @logger.instrument(:present_build_logs) do
         log_artifacts_context(build)
@@ -255,7 +248,8 @@ module Ci
       build_json = @logger.instrument(:present_build_response_json) do
         Gitlab::Json.dump(::API::Entities::Ci::JobRequest::Response.new(presented_build))
       end
-      Result.new(build, build_json, presented_build, true)
+
+      ResultFactory.success(build, build_json, presented_build)
     end
 
     def log_build_dependencies_size(presented_build)
@@ -325,14 +319,40 @@ module Ci
       track_exception_for_build(ex, build)
     end
 
+    def track_success(result, depth)
+      @metrics.register_success(result.build_presented)
+      @metrics.observe_queue_depth(:found, depth)
+    rescue StandardError => ex
+      # We should know about any errors during tracking but we don't want them to prevent
+      # reporting a result to the runner
+      Gitlab::ErrorTracking.track_and_raise_for_dev_exception(
+        ex, **build_tracking_data(result.build)
+      )
+    end
+
+    def track_conflict(depth, valid)
+      @metrics.increment_queue_operation(:queue_conflict) unless valid
+      @metrics.observe_queue_depth(:conflict, depth) unless valid
+      @metrics.observe_queue_depth(:not_found, depth) if valid
+      @metrics.register_failure
+    rescue StandardError => ex
+      # We should know about any errors during tracking but we don't want them to prevent
+      # reporting a result to the runner
+      Gitlab::ErrorTracking.track_and_raise_for_dev_exception(ex)
+    end
+
     def track_exception_for_build(ex, build)
-      Gitlab::ErrorTracking.track_exception(ex,
+      Gitlab::ErrorTracking.track_and_raise_for_dev_exception(ex, **build_tracking_data(build))
+    end
+
+    def build_tracking_data(build)
+      {
         build_id: build.id,
         build_name: build.name,
         build_stage: build.stage_name,
         pipeline_id: build.pipeline_id,
         project_id: build.project_id
-      )
+      }
     end
 
     def pre_assign_runner_checks
