@@ -5,6 +5,8 @@ module ErrorTracking
     private
 
     def perform
+      return error('Access denied', :unauthorized) unless can?(current_user, :admin_sentry, project)
+
       unless project_error_tracking_setting.valid?
         return error(project_error_tracking_setting.errors.full_messages.join(', '), :bad_request)
       end
@@ -19,25 +21,30 @@ module ErrorTracking
     end
 
     def project_error_tracking_setting
-      @project_error_tracking_setting ||= begin
-        (super || project.build_error_tracking_setting).tap do |setting|
-          setting.api_url = ErrorTracking::ProjectErrorTrackingSetting.build_api_url_from(
-            api_host: params[:api_host],
-            organization_slug: 'org',
-            project_slug: 'proj'
-          )
+      (super || project.build_error_tracking_setting).tap do |setting|
+        setting.api_url = ErrorTracking::ProjectErrorTrackingSetting.build_api_url_from(
+          api_host: params[:api_host],
+          organization_slug: 'org',
+          project_slug: 'proj'
+        )
 
-          setting.token = token(setting)
-          setting.enabled = true
-        end
+        setting.token = token(setting)
+        setting.enabled = true
       end
     end
+    strong_memoize_attr :project_error_tracking_setting
 
     def token(setting)
+      return if setting.api_url_changed? && masked_token?
+
       # Use param token if not masked, otherwise use database token
-      return params[:token] unless /\A\*+\z/.match?(params[:token])
+      return params[:token] unless masked_token?
 
       setting.token
     end
+
+    def masked_token?
+      ErrorTracking::SentryClient::Token.masked_token?(params[:token])
+    end
   end
 end
