@@ -2,9 +2,9 @@
 
 module Groups
   module GroupLinks
-    class DestroyService < BaseService
+    class DestroyService < ::Groups::GroupLinks::BaseService
       def execute(one_or_more_links, skip_authorization: false)
-        unless skip_authorization || group && can?(current_user, :admin_group_member, group)
+        unless skip_authorization || (group && can?(current_user, :admin_group_member, group))
           return error('Not Found', 404)
         end
 
@@ -18,13 +18,18 @@ module Groups
           groups_to_refresh.uniq.each do |group|
             next if Feature.enabled?(:skip_group_share_unlink_auth_refresh, group.root_ancestor)
 
-            group.refresh_members_authorized_projects(blocking: false, direct_members_only: true)
+            AuthorizedProjectUpdate::EnqueueGroupMembersRefreshAuthorizedProjectsWorker.perform_async(group.id,
+              { 'priority' => priority_for_refresh, 'direct_members_only' => true })
           end
         else
           Gitlab::AppLogger.info(
             "Failed to delete GroupGroupLinks with ids: #{links.map(&:id)}.")
         end
+
+        links
       end
     end
   end
 end
+
+Groups::GroupLinks::DestroyService.prepend_mod
