@@ -14,7 +14,7 @@ module Issues
     private
 
     def update(issue, attrs)
-      ::Issues::UpdateService.new(project: project, current_user: current_user, params: attrs).execute(issue)
+      ::Issues::UpdateService.new(container: project, current_user: current_user, params: attrs).execute(issue)
     rescue ActiveRecord::RecordNotFound
       false
     end
