@@ -5,6 +5,7 @@ module MergeRequests
     extend ::Gitlab::Utils::Override
     include MergeRequests::AssignsMergeParams
     include MergeRequests::ErrorLogger
+    include Gitlab::Utils::StrongMemoize
 
     delegate :repository, to: :project
 
@@ -88,6 +89,7 @@ module MergeRequests
       merge_request_activity_counter.track_reviewers_changed_action(user: current_user)
       trigger_merge_request_reviewers_updated(merge_request)
 
+      set_reviewers_approved(merge_request, new_reviewers) if new_reviewers.any?
       set_first_reviewer_assigned_at_metrics(merge_request) if new_reviewers.any?
       trigger_user_merge_request_updated(merge_request)
     end
@@ -184,7 +186,6 @@ module MergeRequests
       end
 
       filter_reviewer(merge_request)
-      filter_suggested_reviewers
     end
 
     def filter_reviewer(merge_request)
@@ -213,8 +214,11 @@ module MergeRequests
       end
     end
 
-    def filter_suggested_reviewers
-      # Implemented in EE
+    def set_reviewers_approved(merge_request, new_reviewers)
+      approval_users = merge_request.approvals_for_user_ids(new_reviewers.map(&:id))
+
+      merge_request.merge_request_reviewers_with(approval_users.select(:user_id))
+        .update_all(state: :approved)
     end
 
     def merge_request_metrics_service(merge_request)
@@ -232,7 +236,7 @@ module MergeRequests
     end
 
     def create_pipeline_for(merge_request, user, async: false, allow_duplicate: false)
-      create_pipeline_params = params.slice(:push_options).merge(allow_duplicate: allow_duplicate)
+      create_pipeline_params = params.slice(:push_options, :gitaly_context).merge(allow_duplicate: allow_duplicate)
       service = MergeRequests::CreatePipelineService.new(
         project: project, current_user: user, params: create_pipeline_params
       )
@@ -280,7 +284,7 @@ module MergeRequests
     end
 
     def trigger_user_merge_request_updated(merge_request)
-      [merge_request.assignees, merge_request.reviewers].flatten.uniq.each do |user|
+      [merge_request.author, *merge_request.assignees, *merge_request.reviewers].uniq.each do |user|
         GraphqlTriggers.user_merge_request_updated(user, merge_request)
       end
     end
@@ -314,6 +318,15 @@ module MergeRequests
 
       todo_service.merge_request_became_unmergeable(merge_request)
     end
+
+    def duo_code_review_bot
+      ::Users::Internal.duo_code_review_bot
+    end
+    strong_memoize_attr :duo_code_review_bot
+
+    def invalidate_all_users_cache_count(merge_request)
+      invalidate_cache_counts(merge_request, users: [*merge_request.assignees, *merge_request.reviewers, merge_request.author].uniq)
+    end
   end
 end
 
