@@ -32,7 +32,7 @@ module ResourceEvents
       return events if params[:paginated_notes].nil?
       return events.none if params[:paginated_notes][table_name].blank?
 
-      events.id_in(params[:paginated_notes][table_name].map(&:id))
+      events.id_in(params[:paginated_notes][table_name].flat_map(&:ids))
     end
 
     def apply_last_fetched_at(events)
@@ -44,10 +44,9 @@ module ResourceEvents
     end
 
     def resource_parent
-      strong_memoize(:resource_parent) do
-        resource.project || resource.group
-      end
+      resource.try(:resource_parent) || resource.project || resource.group
     end
+    strong_memoize_attr :resource_parent
 
     def table_name
       raise NotImplementedError
