@@ -21,6 +21,9 @@ module Timelogs
           }, 404)
       end
 
+      return error(_("Spent at can't be a future date and time."), 404) if spent_at.future?
+      return error(_("Time spent can't be zero."), 404) if time_spent == 0
+
       issue = issuable if issuable.is_a?(Issue)
       merge_request = issuable if issuable.is_a?(MergeRequest)
 
@@ -34,12 +37,35 @@ module Timelogs
         note: nil
       )
 
+      old_associations = { total_time_spent: issuable.total_time_spent }
+
       if !timelog.save
         error_in_save(timelog)
       else
+        issuable.reset
+
         SystemNoteService.created_timelog(issuable, issuable.project, current_user, timelog)
+
+        issuable_base_service.execute_hooks(issuable, 'update', old_associations: old_associations)
+
         success(timelog)
       end
     end
+
+    private
+
+    def issuable_base_service
+      if issuable.is_a?(Issue)
+        Issues::BaseService.new(
+          container: issuable.project,
+          current_user: current_user
+        )
+      else
+        MergeRequests::BaseService.new(
+          project: issuable.project,
+          current_user: current_user
+        )
+      end
+    end
   end
 end
