@@ -47,6 +47,7 @@ module Users
       migrate_reviews
       migrate_releases
       migrate_timelogs
+      migrate_pipelines
     end
 
     def post_migrate_records
@@ -55,6 +56,7 @@ module Users
       # Rails attempts to load all related records into memory before
       # destroying: https://github.com/rails/rails/issues/22510
       # This ensures we delete records in batches.
+      user.delete_dependent_associations_in_batches(exclude: [:project_authorizations])
       user.destroy_dependent_associations_in_batches(exclude: [:snippets])
       user.nullify_dependent_associations_in_batches
 
@@ -86,6 +88,9 @@ module Users
 
     def migrate_notes
       batched_migrate(Note, :author_id)
+
+      # Migrate label change event system notes as they are stored in a different table
+      batched_migrate(ResourceLabelEvent, :user_id)
     end
 
     def migrate_abuse_reports
@@ -118,6 +123,11 @@ module Users
       batched_migrate(Timelog, :user_id)
     end
 
+    def migrate_pipelines
+      batched_migrate(Ci::Pipeline, :user_id)
+      batched_migrate(Ci::Build, :user_id)
+    end
+
     # rubocop:disable CodeReuse/ActiveRecord
     def batched_migrate(base_scope, column, batch_size: 50)
       loop do
