@@ -4,12 +4,25 @@ module Pages
   class DeploymentUploader < GitlabUploader
     include ObjectStorage::Concern
 
-    storage_options Gitlab.config.pages
+    storage_location :pages
 
     alias_method :upload, :model
 
+    def filename
+      trim_filename_if_needed(super)
+    end
+
     private
 
+    # Trims filename to 60 characters from the front if it exceeds that length
+    def trim_filename_if_needed(filename)
+      return if filename.nil?
+      return filename if filename.length <= 60
+
+      # Take the last 60 characters
+      filename[-60..]
+    end
+
     def dynamic_segment
       Gitlab::HashedPath.new('pages_deployments', model.id, root_hash: model.project_id)
     end
@@ -36,16 +49,11 @@ module Pages
         false
       end
 
-      # we don't need background uploads because we upload files
-      # to the right store right away, and we already do that in
-      # the background job
-      def background_upload_enabled?
-        false
-      end
-
       def default_store
         object_store_enabled? ? ObjectStorage::Store::REMOTE : ObjectStorage::Store::LOCAL
       end
     end
   end
 end
+
+Pages::DeploymentUploader.prepend_mod
