@@ -8,18 +8,16 @@ module Gitlab
 
         data_consistency :always
 
-        sidekiq_options retry: 3
-        include GithubImport::Queue
         include StageMethods
 
-        # technical debt: https://gitlab.com/gitlab-org/gitlab/issues/33991
-        sidekiq_options memory_killer_memory_growth_kb: ENV.fetch('MEMORY_KILLER_FINISH_IMPORT_WORKER_MEMORY_GROWTH_KB', 50).to_i
-        sidekiq_options memory_killer_max_memory_growth_kb: ENV.fetch('MEMORY_KILLER_FINISH_IMPORT_WORKER_MAX_MEMORY_GROWTH_KB', 200_000).to_i
-
         # project - An instance of Project.
         def import(_, project)
           @project = project
+
+          return self.class.perform_in(30.seconds, project.id) if reference_store_pending?
+
           project.after_import
+
           report_import_time
         end
 
@@ -27,6 +25,27 @@ module Gitlab
 
         attr_reader :project
 
+        def reference_store_pending?
+          import_settings = import_settings(project)
+
+          return false unless import_settings.user_mapping_enabled?
+          return false if import_settings.map_to_personal_namespace_owner?
+          return false unless placeholder_reference_store.any?
+
+          ::Import::LoadPlaceholderReferencesWorker.perform_async(
+            ::Import::SOURCE_GITHUB,
+            project.import_state.id
+          )
+
+          info(
+            project.id,
+            message: 'Delaying finalization as placeholder references are pending',
+            placeholder_store_count: placeholder_reference_store.count
+          )
+
+          true
+        end
+
         def report_import_time
           metrics.track_finished_import
 
@@ -41,6 +60,10 @@ module Gitlab
         def metrics
           @metrics ||= Gitlab::Import::Metrics.new(:github_importer, project)
         end
+
+        def placeholder_reference_store
+          @placeholder_reference_store ||= project.placeholder_reference_store
+        end
       end
     end
   end
