@@ -9,11 +9,11 @@ module Namespaces
 
     data_consistency :always
 
-    feature_category :pods
+    feature_category :cell
     urgency :high
 
     idempotent!
-    deduplicate :until_executed, if_deduplicated: :reschedule_once
+    deduplicate :until_executed, if_deduplicated: :reschedule_once, ttl: 1.minute
 
     def perform
       results = ::Ci::ProcessSyncEventsService.new(
