@@ -71,11 +71,7 @@ Rails.application.configure do
   # Don't make a mess when bootstrapping a development environment
   config.action_mailer.perform_deliveries = (ENV['BOOTSTRAP'] != '1')
 
-  if ::Gitlab.next_rails?
-    config.action_mailer.preview_paths = [GitlabEdition.path_glob('app/mailers/previews')]
-  else
-    config.action_mailer.preview_path = GitlabEdition.path_glob('app/mailers/previews')
-  end
+  config.action_mailer.preview_paths = [GitlabEdition.path_glob('app/mailers/previews')]
 
   config.eager_load = false
 
