@@ -247,6 +247,7 @@ Settings.gitlab['trusted_proxies'] ||= []
 Settings.gitlab['content_security_policy'] ||= {}
 Settings.gitlab['allowed_hosts'] ||= []
 Settings.gitlab['impersonation_enabled'] ||= true if Settings.gitlab['impersonation_enabled'].nil?
+Settings.gitlab['server_fqdn'] ||= Settings.__send__(:build_server_fqdn)
 Settings.gitlab['usage_ping_enabled'] = true if Settings.gitlab['usage_ping_enabled'].nil?
 Settings.gitlab['max_request_duration_seconds'] ||= 57
 Settings.gitlab['display_initial_root_password'] = false if Settings.gitlab['display_initial_root_password'].nil?
@@ -254,6 +255,9 @@ Settings.gitlab['weak_passwords_digest_set'] ||= YAML.safe_load(File.open(Rails.
 Settings.gitlab['log_decompressed_response_bytesize'] = ENV["GITLAB_LOG_DECOMPRESSED_RESPONSE_BYTESIZE"].to_i > 0 ? ENV["GITLAB_LOG_DECOMPRESSED_RESPONSE_BYTESIZE"].to_i : 0
 Settings.gitlab['initial_gitlab_product_usage_data'] = true if Settings.gitlab['initial_gitlab_product_usage_data'].nil?
 
+Settings['ci_id_tokens'] ||= {}
+Settings.ci_id_tokens['issuer_url'] = Settings.gitlab.url if Settings.ci_id_tokens['issuer_url'].blank?
+
 Gitlab.ee do
   Settings.gitlab['mirror_max_delay'] ||= 300
   Settings.gitlab['mirror_max_capacity'] ||= 30
@@ -279,7 +283,6 @@ Settings.gitlab_ci['shared_runners_enabled'] = true if Settings.gitlab_ci['share
 # If you are changing default storage paths, then you must change them in the gitlab-backup-cli gem as well
 Settings.gitlab_ci['builds_path']           = Settings.absolute(Settings.gitlab_ci['builds_path'] || "builds/")
 Settings.gitlab_ci['url']                 ||= Settings.__send__(:build_gitlab_ci_url)
-Settings.gitlab_ci['server_fqdn']         ||= Settings.__send__(:build_ci_server_fqdn)
 
 #
 # CI Secure Files
@@ -357,6 +360,9 @@ Settings.pages['protocol'] ||= Settings.pages.https ? "https" : "http"
 Settings.pages['url'] ||= Settings.__send__(:build_pages_url)
 Settings.pages['external_http'] ||= false unless Settings.pages['external_http'].present?
 Settings.pages['external_https'] ||= false unless Settings.pages['external_https'].present?
+Settings.pages['custom_domain_mode'] = 'http' if Settings.pages['external_http'].present?
+Settings.pages['custom_domain_mode'] = 'https' if Settings.pages['external_https'].present?
+Settings.pages['custom_domain_mode'] = nil unless Settings.pages['custom_domain_mode'].present?
 Settings.pages['artifacts_server'] ||= Settings.pages['enabled'] if Settings.pages['artifacts_server'].nil?
 Settings.pages['secret_file'] ||= Rails.root.join('.gitlab_pages_secret')
 # We want pages zip archives to be stored on the same directory as old pages hierarchical structure
@@ -381,8 +387,8 @@ Settings.gitlab_docs['host'] = nil unless Settings.gitlab_docs.enabled
 #
 Gitlab.ee do
   Settings['geo'] ||= {}
-  # For backwards compatibility, default to gitlab_url and if so, ensure it ends with "/"
-  Settings.geo['node_name'] = Settings.geo['node_name'].presence || Settings.gitlab['url'].chomp('/').concat('/')
+  # For backwards compatibility, default to gitlab_url
+  Settings.geo['node_name'] = Settings.geo['node_name'].presence || Settings.gitlab['url']
 
   #
   # Registry replication
@@ -494,6 +500,12 @@ if Gitlab.ee? && Settings['ee_cron_jobs']
   Settings.cron_jobs.merge!(Settings.ee_cron_jobs)
 end
 
+Settings.cron_jobs['adjourned_group_deletion_worker'] ||= {}
+Settings.cron_jobs['adjourned_group_deletion_worker']['cron'] ||= '0 2 * * *'
+Settings.cron_jobs['adjourned_group_deletion_worker']['job_class'] = 'AdjournedGroupDeletionWorker'
+Settings.cron_jobs['adjourned_projects_deletion_cron_worker'] ||= {}
+Settings.cron_jobs['adjourned_projects_deletion_cron_worker']['cron'] ||= '0 7 * * *'
+Settings.cron_jobs['adjourned_projects_deletion_cron_worker']['job_class'] = 'AdjournedProjectsDeletionCronWorker'
 Settings.cron_jobs['poll_interval'] ||= ENV["GITLAB_CRON_JOBS_POLL_INTERVAL"] ? ENV["GITLAB_CRON_JOBS_POLL_INTERVAL"].to_i : nil
 Settings.cron_jobs['stuck_ci_jobs_worker'] ||= {}
 Settings.cron_jobs['stuck_ci_jobs_worker']['cron'] ||= '0 * * * *'
@@ -531,6 +543,9 @@ Settings.cron_jobs['admin_email_worker']['job_class'] = 'AdminEmailWorker'
 Settings.cron_jobs['personal_access_tokens_expiring_worker'] ||= {}
 Settings.cron_jobs['personal_access_tokens_expiring_worker']['cron'] ||= '0 1 * * *'
 Settings.cron_jobs['personal_access_tokens_expiring_worker']['job_class'] = 'PersonalAccessTokens::ExpiringWorker'
+Settings.cron_jobs['deploy_tokens_expiring_worker'] ||= {}
+Settings.cron_jobs['deploy_tokens_expiring_worker']['cron'] ||= '0 1 * * *'
+Settings.cron_jobs['deploy_tokens_expiring_worker']['job_class'] = 'DeployTokens::ExpiringWorker'
 Settings.cron_jobs['personal_access_tokens_expired_notification_worker'] ||= {}
 Settings.cron_jobs['personal_access_tokens_expired_notification_worker']['cron'] ||= '0 2 * * *'
 Settings.cron_jobs['personal_access_tokens_expired_notification_worker']['job_class'] = 'PersonalAccessTokens::ExpiredNotificationWorker'
@@ -678,6 +693,9 @@ Settings.cron_jobs['batched_background_migrations_worker']['job_class'] = 'Datab
 Settings.cron_jobs['batched_background_migration_worker_ci_database'] ||= {}
 Settings.cron_jobs['batched_background_migration_worker_ci_database']['cron'] ||= '* * * * *'
 Settings.cron_jobs['batched_background_migration_worker_ci_database']['job_class'] = 'Database::BatchedBackgroundMigration::CiDatabaseWorker'
+Settings.cron_jobs['batched_background_migration_worker_sec_database'] ||= {}
+Settings.cron_jobs['batched_background_migration_worker_sec_database']['cron'] ||= '* * * * *'
+Settings.cron_jobs['batched_background_migration_worker_sec_database']['job_class'] = 'Database::BatchedBackgroundMigration::SecDatabaseWorker'
 Settings.cron_jobs['issues_reschedule_stuck_issue_rebalances'] ||= {}
 Settings.cron_jobs['issues_reschedule_stuck_issue_rebalances']['cron'] ||= '*/15 * * * *'
 Settings.cron_jobs['issues_reschedule_stuck_issue_rebalances']['job_class'] = 'Issues::RescheduleStuckIssueRebalancesWorker'
@@ -690,6 +708,9 @@ Settings.cron_jobs['inactive_projects_deletion_cron_worker']['job_class'] = 'Pro
 Settings.cron_jobs['loose_foreign_keys_cleanup_worker'] ||= {}
 Settings.cron_jobs['loose_foreign_keys_cleanup_worker']['cron'] ||= '*/1 * * * *'
 Settings.cron_jobs['loose_foreign_keys_cleanup_worker']['job_class'] = 'LooseForeignKeys::CleanupWorker'
+Settings.cron_jobs['loose_foreign_keys_merge_request_diff_commit_cleanup_worker'] ||= {}
+Settings.cron_jobs['loose_foreign_keys_merge_request_diff_commit_cleanup_worker']['cron'] ||= '*/1 * * * *'
+Settings.cron_jobs['loose_foreign_keys_merge_request_diff_commit_cleanup_worker']['job_class'] = 'LooseForeignKeys::MergeRequestDiffCommitCleanupWorker'
 Settings.cron_jobs['batched_git_ref_updates_cleanup_scheduler_worker'] ||= {}
 Settings.cron_jobs['batched_git_ref_updates_cleanup_scheduler_worker']['cron'] ||= '*/1 * * * *'
 Settings.cron_jobs['batched_git_ref_updates_cleanup_scheduler_worker']['job_class'] = 'BatchedGitRefUpdates::CleanupSchedulerWorker'
@@ -730,7 +751,7 @@ Settings.cron_jobs['performance_bar_stats'] ||= {}
 Settings.cron_jobs['performance_bar_stats']['cron'] ||= '*/2 * * * *'
 Settings.cron_jobs['performance_bar_stats']['job_class'] = 'GitlabPerformanceBarStatsWorker'
 Settings.cron_jobs['ci_catalog_resources_aggregate_last30_day_usage_worker'] ||= {}
-Settings.cron_jobs['ci_catalog_resources_aggregate_last30_day_usage_worker']['cron'] ||= '*/4 * * * *'
+Settings.cron_jobs['ci_catalog_resources_aggregate_last30_day_usage_worker']['cron'] ||= '0 0 * * *'
 Settings.cron_jobs['ci_catalog_resources_aggregate_last30_day_usage_worker']['job_class'] = 'Ci::Catalog::Resources::AggregateLast30DayUsageWorker'
 Settings.cron_jobs['ci_catalog_resources_cleanup_last_usages_worker'] ||= {}
 Settings.cron_jobs['ci_catalog_resources_cleanup_last_usages_worker']['cron'] ||= '0 0 * * *'
@@ -785,12 +806,6 @@ Gitlab.ee do
   Settings.cron_jobs['active_user_count_threshold_worker'] ||= {}
   Settings.cron_jobs['active_user_count_threshold_worker']['cron'] ||= '0 12 * * *'
   Settings.cron_jobs['active_user_count_threshold_worker']['job_class'] = 'ActiveUserCountThresholdWorker'
-  Settings.cron_jobs['adjourned_group_deletion_worker'] ||= {}
-  Settings.cron_jobs['adjourned_group_deletion_worker']['cron'] ||= '0 2 * * *'
-  Settings.cron_jobs['adjourned_group_deletion_worker']['job_class'] = 'AdjournedGroupDeletionWorker'
-  Settings.cron_jobs['adjourned_projects_deletion_cron_worker'] ||= {}
-  Settings.cron_jobs['adjourned_projects_deletion_cron_worker']['cron'] ||= '0 7 * * *'
-  Settings.cron_jobs['adjourned_projects_deletion_cron_worker']['job_class'] = 'AdjournedProjectsDeletionCronWorker'
   Settings.cron_jobs['geo_verification_cron_worker'] ||= {}
   Settings.cron_jobs['geo_verification_cron_worker']['cron'] ||= '* * * * *'
   Settings.cron_jobs['geo_verification_cron_worker']['job_class'] ||= 'Geo::VerificationCronWorker'
@@ -827,9 +842,6 @@ Gitlab.ee do
   Settings.cron_jobs['incident_management_schedule_escalation_check_worker'] ||= {}
   Settings.cron_jobs['incident_management_schedule_escalation_check_worker']['cron'] ||= '*/1 * * * *'
   Settings.cron_jobs['incident_management_schedule_escalation_check_worker']['job_class'] = 'IncidentManagement::PendingEscalations::ScheduleCheckCronWorker'
-  Settings.cron_jobs['import_software_licenses_worker'] ||= {}
-  Settings.cron_jobs['import_software_licenses_worker']['cron'] ||= '0 3 * * 0'
-  Settings.cron_jobs['import_software_licenses_worker']['job_class'] = 'ImportSoftwareLicensesWorker'
   Settings.cron_jobs['ldap_group_sync_worker'] ||= {}
   Settings.cron_jobs['ldap_group_sync_worker']['cron'] ||= '0 * * * *'
   Settings.cron_jobs['ldap_group_sync_worker']['job_class'] = 'LdapAllGroupsSyncWorker'
@@ -837,11 +849,11 @@ Gitlab.ee do
   Settings.cron_jobs['ldap_sync_worker']['cron'] ||= '30 1 * * *'
   Settings.cron_jobs['ldap_sync_worker']['job_class'] = 'LdapSyncWorker'
   Settings.cron_jobs['ldap_admin_sync_worker'] ||= {}
-  Settings.cron_jobs['ldap_admin_sync_worker']['cron'] ||= '30 3 * * *'
+  Settings.cron_jobs['ldap_admin_sync_worker']['cron'] ||= '0 * * * *'
   Settings.cron_jobs['ldap_admin_sync_worker']['job_class'] = 'Authz::LdapAdminRoleWorker'
-  Settings.cron_jobs['queue_refresh_of_broken_adherence_groups_worker'] ||= {}
-  Settings.cron_jobs['queue_refresh_of_broken_adherence_groups_worker']['cron'] ||= '*/20 * * * *'
-  Settings.cron_jobs['queue_refresh_of_broken_adherence_groups_worker']['job_class'] = 'ComplianceManagement::QueueRefreshOfBrokenAdherenceGroupsWorker'
+  Settings.cron_jobs['ldap_add_on_seat_sync_worker'] ||= {}
+  Settings.cron_jobs['ldap_add_on_seat_sync_worker']['cron'] ||= '0 2 * * *'
+  Settings.cron_jobs['ldap_add_on_seat_sync_worker']['job_class'] = 'GitlabSubscriptions::AddOnPurchases::LdapAllAddOnSeatSyncWorker'
   Settings.cron_jobs['elastic_index_bulk_cron_worker'] ||= {}
   Settings.cron_jobs['elastic_index_bulk_cron_worker']['cron'] ||= '*/1 * * * *'
   Settings.cron_jobs['elastic_index_bulk_cron_worker']['job_class'] ||= 'ElasticIndexBulkCronWorker'
@@ -911,6 +923,9 @@ Gitlab.ee do
   Settings.cron_jobs['vulnerability_orphaned_remediations_cleanup_worker'] ||= {}
   Settings.cron_jobs['vulnerability_orphaned_remediations_cleanup_worker']['job_class'] = 'Vulnerabilities::OrphanedRemediationsCleanupWorker'
   Settings.cron_jobs['vulnerability_orphaned_remediations_cleanup_worker']['cron'] ||= '15 3 * * */6'
+  Settings.cron_jobs['security_analyzer_namespace_statuses_schedule_worker'] ||= {}
+  Settings.cron_jobs['security_analyzer_namespace_statuses_schedule_worker']['cron'] ||= '0 8 * * 0'
+  Settings.cron_jobs['security_analyzer_namespace_statuses_schedule_worker']['job_class'] = 'Security::AnalyzerNamespaceStatuses::ScheduleWorker'
   Settings.cron_jobs['security_create_orchestration_policy_worker'] ||= {}
   Settings.cron_jobs['security_create_orchestration_policy_worker']['cron'] ||= '*/10 * * * *'
   Settings.cron_jobs['security_create_orchestration_policy_worker']['job_class'] = 'Security::CreateOrchestrationPolicyWorker'
@@ -920,9 +935,15 @@ Gitlab.ee do
   Settings.cron_jobs['security_pipeline_execution_policies_schedule_worker'] ||= {}
   Settings.cron_jobs['security_pipeline_execution_policies_schedule_worker']['cron'] ||= '* * * * *'
   Settings.cron_jobs['security_pipeline_execution_policies_schedule_worker']['job_class'] = 'Security::PipelineExecutionPolicies::ScheduleWorker'
+  Settings.cron_jobs['users_security_policy_bot_cleanup_cron_worker'] ||= {}
+  Settings.cron_jobs['users_security_policy_bot_cleanup_cron_worker']['cron'] ||= '0 * * * *'
+  Settings.cron_jobs['users_security_policy_bot_cleanup_cron_worker']['job_class'] = 'Users::SecurityPolicyBotCleanupCronWorker'
   Settings.cron_jobs['security_scans_purge_worker'] ||= {}
   Settings.cron_jobs['security_scans_purge_worker']['cron'] ||= '0 */4 * * 6,0'
   Settings.cron_jobs['security_scans_purge_worker']['job_class'] = 'Security::Scans::PurgeWorker'
+  Settings.cron_jobs['security_destroy_expired_sbom_scans_worker'] ||= {}
+  Settings.cron_jobs['security_destroy_expired_sbom_scans_worker']['cron'] ||= '0 2 * * *'
+  Settings.cron_jobs['security_destroy_expired_sbom_scans_worker']['job_class'] = 'Security::VulnerabilityScanning::DestroyExpiredSbomScansWorker'
   Settings.cron_jobs['app_sec_dast_profile_schedule_worker'] ||= {}
   Settings.cron_jobs['app_sec_dast_profile_schedule_worker']['cron'] ||= '7-59/15 * * * *'
   Settings.cron_jobs['app_sec_dast_profile_schedule_worker']['job_class'] = 'AppSec::Dast::ProfileScheduleWorker'
@@ -975,6 +996,9 @@ Gitlab.ee do
   Settings.cron_jobs['click_house_user_add_on_assignments_sync_worker'] ||= {}
   Settings.cron_jobs['click_house_user_add_on_assignments_sync_worker']['cron'] = "*/3 * * * *"
   Settings.cron_jobs['click_house_user_add_on_assignments_sync_worker']['job_class'] = 'ClickHouse::UserAddOnAssignmentsSyncWorker'
+  Settings.cron_jobs['click_house_user_addon_assignment_versions_sync'] ||= {}
+  Settings.cron_jobs['click_house_user_addon_assignment_versions_sync']['cron'] = "*/3 * * * *"
+  Settings.cron_jobs['click_house_user_addon_assignment_versions_sync']['job_class'] = 'ClickHouse::UserAddonAssignmentVersionsSyncWorker'
   Settings.cron_jobs['click_house_event_authors_consistency_cron_worker'] ||= {}
   Settings.cron_jobs['click_house_event_authors_consistency_cron_worker']['cron'] ||= "*/30 * * * *"
   Settings.cron_jobs['click_house_event_authors_consistency_cron_worker']['job_class'] = 'ClickHouse::EventAuthorsConsistencyCronWorker'
@@ -1017,6 +1041,9 @@ Gitlab.ee do
   Settings.cron_jobs['ai_active_context_bulk_process_worker'] ||= {}
   Settings.cron_jobs['ai_active_context_bulk_process_worker']['cron'] ||= '*/1 * * * *'
   Settings.cron_jobs['ai_active_context_bulk_process_worker']['job_class'] ||= 'Ai::ActiveContext::BulkProcessWorker'
+  Settings.cron_jobs['ai_active_context_code_scheduling_worker'] ||= {}
+  Settings.cron_jobs['ai_active_context_code_scheduling_worker']['cron'] ||= '*/1 * * * *'
+  Settings.cron_jobs['ai_active_context_code_scheduling_worker']['job_class'] ||= 'Ai::ActiveContext::Code::SchedulingWorker'
   Settings.cron_jobs['ai_active_context_migration_worker'] ||= {}
   Settings.cron_jobs['ai_active_context_migration_worker']['cron'] ||= '*/5 * * * *'
   Settings.cron_jobs['ai_active_context_migration_worker']['job_class'] ||= 'Ai::ActiveContext::MigrationWorker'
@@ -1064,6 +1091,10 @@ Gitlab.ee do
     Settings.cron_jobs['delete_pipl_users_worker']['cron'] ||= '0 8 * * *'
     Settings.cron_jobs['delete_pipl_users_worker']['job_class'] =
       'ComplianceManagement::Pipl::DeletePiplUsersWorker'
+
+    Settings.cron_jobs['cleanup_build_name_worker'] ||= {}
+    Settings.cron_jobs['cleanup_build_name_worker']['cron'] ||= '0 1 * * *'
+    Settings.cron_jobs['cleanup_build_name_worker']['job_class'] = 'Ci::CleanupBuildNameWorker'
   end
 
   Gitlab.jh do
@@ -1104,6 +1135,15 @@ ObjectStoreSettings.new(Settings).parse!
 Settings['workhorse'] ||= {}
 Settings.workhorse['secret_file'] ||= Rails.root.join('.gitlab_workhorse_secret')
 
+#
+# Database Traffic Capture Settings
+#
+
+Settings['database_traffic_capture'] ||= {}
+Settings.database_traffic_capture['config'] ||= {}
+Settings.database_traffic_capture.config['storage'] ||= {}
+Settings.database_traffic_capture.config.storage['connector'] ||= {}
+
 #
 # Cells
 #
@@ -1112,13 +1152,16 @@ Settings.cell['enabled'] ||= false # All Cells Features are disabled by default
 Settings.cell['id'] ||= nil
 Settings.cell['database'] ||= {}
 Settings.cell.database['skip_sequence_alteration'] ||= false
-
-# Topology Service Client Settings
+# NOTE: `topology_service_client` is the configuration to use going forward as per https://docs.gitlab.com/administration/cells/#configuration
+#   We continue to be backwards compatible and support `topology_service` as a top-level key.
 Settings.cell['topology_service_client'] ||= Settings.respond_to?(:topology_service) ? Settings.topology_service || {} : {}
-Settings.cell.topology_service_client['address'] ||= 'topology-service.gitlab.example.com:443'
-Settings.cell.topology_service_client['ca_file'] ||= '/var/lib/gitlab/config/topology-service-ca.pem'
-Settings.cell.topology_service_client['certificate_file'] ||= '/var/lib/gitlab/config/topology-service-cert.pem'
-Settings.cell.topology_service_client['private_key_file'] ||= '/var/lib/gitlab/config/topology-service-key.pem'
+Settings.cell.topology_service_client['address'] ||= 'topology-service.example.com:443'
+Settings.cell.topology_service_client['ca_file'] ||= nil
+Settings.cell.topology_service_client['certificate_file'] ||= nil
+Settings.cell.topology_service_client['private_key_file'] ||= nil
+Settings.cell.topology_service_client['tls'] ||= {}
+Settings.cell.topology_service_client['tls']['enabled'] = true if Settings.cell.topology_service_client['tls']['enabled'].nil?
+Settings.cell.topology_service_client['metadata'] ||= {}
 
 #
 # GitLab KAS
@@ -1161,8 +1204,10 @@ Gitlab.ee do
     "https://gitlab.com/api/v4/projects/58711783/packages/generic/duo-workflow-executor/#{executor_version}/#{os_info.sub('/', '-')}-duo-workflow-executor.tar.gz"
   end
 
+  secure = Gitlab::Utils.to_boolean(ENV['DUO_AGENT_PLATFORM_SERVICE_SECURE'], default: true)
+
   Settings.duo_workflow.reverse_merge!(
-    secure: true,
+    secure: secure,
     service_url: nil, # service_url is constructued in Gitlab::DuoWorkflow::Client
     debug: false,
     executor_binary_url: "https://gitlab.com/api/v4/projects/58711783/packages/generic/duo-workflow-executor/#{executor_version}/duo-workflow-executor.tar.gz",
@@ -1365,7 +1410,8 @@ Settings.prometheus['server_address'] ||= nil
 # Bullet settings
 #
 Settings['bullet'] ||= {}
-Settings.bullet['enabled'] ||= Rails.env.development?
+Settings.bullet['enabled'] = Gitlab::Utils.to_boolean(ENV['ENABLE_BULLET'], default: Settings.bullet['enabled'])
+Settings.bullet['enabled'] = Rails.env.development? if Settings.bullet['enabled'].nil?
 
 #
 # Shutdown settings
