@@ -7,3 +7,9 @@ return unless Gitlab::Runtime.puma?
 Gitlab::Cluster::LifecycleEvents.on_worker_start do
   Gitlab::Memory::ReportsDaemon.instance.start
 end
+
+Gitlab::Cluster::LifecycleEvents.on_worker_stop do
+  Gitlab::Memory::Reporter.new.run_report(
+    Gitlab::Memory::Reports::HeapDump.new
+  )
+end
