@@ -12,12 +12,16 @@
 # end
 #
 ActiveSupport::Inflector.inflections do |inflect|
-  inflect.uncountable %w(
+  inflect.uncountable %w[
     custom_emoji
     award_emoji
     ci_secure_file_registry
     container_repository_registry
-    design_registry
+    dependency_proxy_blob_registry
+    design_management_repository_registry
+    dependency_proxy_manifest_registry
+    duo_enterprise
+    duo_pro
     event_log
     file_registry
     group_view
@@ -30,13 +34,17 @@ ActiveSupport::Inflector.inflections do |inflect|
     pipeline_artifact_registry
     project_auto_devops
     project_registry
+    project_wiki_repository_registry
+    project_repository_registry
     project_statistics
     snippet_repository_registry
     system_note_metadata
     terraform_state_version_registry
     vulnerabilities_feedback
     vulnerability_feedback
-  )
+    wiki_page_meta
+    WikiPage::Meta
+  ]
   inflect.acronym 'CDN'
   inflect.acronym 'EE'
   inflect.acronym 'JH'
