@@ -57,7 +57,11 @@ namespace :admin do
     put 'renew', on: :member
   end
 
-  resources :groups, only: [:index, :new, :create]
+  resources :groups, only: [:index, :new, :create] do
+    collection do
+      get :active, :inactive, to: 'groups#index'
+    end
+  end
 
   resources :organizations, only: [:index]
 
@@ -116,10 +120,22 @@ namespace :admin do
 
   resource :health_check, controller: 'health_check', only: [:show]
   resource :background_jobs, controller: 'background_jobs', only: [:show]
+  resources :database_diagnostics, controller: 'database_diagnostics', only: [:index] do
+    collection do
+      post :run_collation_check
+      get :collation_check_results
+      post :run_schema_check
+      get :schema_check_results
+    end
+  end
 
   resource :system_info, controller: 'system_info', only: [:show]
 
-  resources :projects, only: [:index]
+  resources :projects, only: [:index] do
+    collection do
+      get :active, :inactive, to: 'projects#index'
+    end
+  end
 
   resources :usage_trends, only: :index
   resource :dev_ops_reports, controller: 'dev_ops_report', only: :show
