@@ -4,6 +4,8 @@ module Db
       class AbuseReport
         def self.seed
           Gitlab::Seeder.quiet do
+            organization = User.admins.first.organizations.first
+
             (::AbuseReport.default_per_page + 3).times do |i|
               username = "#{::Gitlab::Seeder::REPORTED_USER_START}#{::Gitlab::Faker::Internet.unique_username}"
               reported_user =
@@ -14,7 +16,7 @@ module Db
                   confirmed_at: DateTime.now,
                   password: ::User.random_password
                 ) do |user|
-                  user.assign_personal_namespace(Organizations::Organization.default_organization)
+                  user.assign_personal_namespace(organization)
                 end
 
               label_title = "abuse_report_label_#{FactoryBot.generate(:label_title)}"
