@@ -3,11 +3,15 @@ require 'mime/types'
 
 module API
   class Commits < ::API::Base
+    include ::API::Concerns::AiWorkflowsAccess
+    include APIGuard
     include PaginationParams
     include Helpers::Unidiff
 
     helpers ::API::Helpers::NotesHelpers
 
+    allow_ai_workflows_access
+
     feature_category :source_code_management
 
     before do
@@ -30,8 +34,14 @@ module API
         end
       end
 
-      def track_commit_events
-        return unless find_user_from_warden
+      def web_ide_request?
+        return false unless access_token.respond_to?(:application)
+
+        access_token.application.id == WebIde::DefaultOauthApplication.oauth_application_id
+      end
+
+      def track_web_ide_commit_events
+        return unless web_ide_request?
 
         Gitlab::InternalEvents.track_event('create_commit_from_web_ide', user: current_user, project: user_project)
         Gitlab::InternalEvents.track_event('g_edit_by_web_ide', user: current_user, project: user_project)
@@ -247,7 +257,7 @@ module API
         if result[:status] == :success
           commit_detail = user_project.repository.commit(result[:result])
 
-          track_commit_events
+          track_web_ide_commit_events
 
           present commit_detail, with: Entities::CommitDetail, include_stats: params[:stats], current_user: current_user
         else
@@ -266,6 +276,9 @@ module API
         requires :sha, type: String, desc: 'A commit sha, or the name of a branch or tag'
         optional :stats, type: Boolean, default: true, desc: 'Include commit stats'
       end
+      route_setting :authentication, job_token_allowed: true
+      route_setting :authorization, job_token_policies: :read_repositories,
+        allow_public_access_for_enabled_project_features: :repository
       get ':id/repository/commits/:sha', requirements: API::COMMIT_ENDPOINT_REQUIREMENTS do
         commit = user_project.commit(params[:sha])
 
@@ -313,7 +326,7 @@ module API
         commit = user_project.commit(params[:sha])
 
         not_found! 'Commit' unless commit
-        notes = commit.notes.with_api_entity_associations.fresh
+        notes = commit.notes.with_api_entity_associations.order_created_at_id_asc
 
         present paginate(notes), with: Entities::CommitNote
       end
@@ -468,12 +481,32 @@ module API
         commit = user_project.commit(params[:sha])
         not_found!('Commit') unless commit
 
-        refs = []
-        refs.concat(user_project.repository.branch_names_contains(commit.id).map { |name| { type: 'branch', name: name } }) unless params[:type] == 'tag'
-        refs.concat(user_project.repository.tag_names_contains(commit.id).map { |name| { type: 'tag', name: name } }) unless params[:type] == 'branch'
+        page = params[:page] > 0 ? params[:page] : 1
+        per_page = params[:per_page] > 0 ? params[:per_page] : Kaminari.config.default_per_page
+
+        # Gitaly RPC doesn't support pagination, but we still can limit the number of requested records
+        # Example: per_page = 50, page = 3
+        # Limit will be set to 151 to capture enough records for Kaminari pagination to extract the right slice.
+        # 1 is added to the limit so that Kaminari knows there are more records and correctly sets the x-next-page
+        # and Link headers.
+        limit = ([per_page, Kaminari.config.max_per_page].min * page) + 1
+
+        args = {
+          type: declared_params[:type],
+          limit: limit
+        }.compact
+
+        refs = ::Gitlab::Repositories::ContainingCommitFinder.new(
+          user_project.repository,
+          commit.id,
+          args
+        ).execute
+
         refs = Kaminari.paginate_array(refs)
 
-        present paginate(refs), with: Entities::BasicRef
+        # Due to the limit applied above to capture just enough records, disable x-total, x-total-page, and "last" link
+        # in the response header. Without this, the response headers would contain incorrect and misleading values.
+        present paginate(refs, without_count: true), with: Entities::BasicRef
       end
 
       desc 'Post comment to commit' do
@@ -547,8 +580,12 @@ module API
       end
       params do
         requires :sha, type: String, desc: 'A commit sha, or the name of a branch or tag on which to find Merge Requests'
+        optional :state, type: String, desc: 'Filter merge-requests by state', documentation: { example: 'merged' }
         use :pagination
       end
+      route_setting :authentication, job_token_allowed: true
+      route_setting :authorization, job_token_policies: :read_repositories,
+        allow_public_access_for_enabled_project_features: [:repository, :merge_requests]
       get ':id/repository/commits/:sha/merge_requests', requirements: API::COMMIT_ENDPOINT_REQUIREMENTS, urgency: :low do
         authorize! :read_merge_request, user_project
 
@@ -558,7 +595,8 @@ module API
         commit_merge_requests = MergeRequestsFinder.new(
           current_user,
           project_id: user_project.id,
-          commit_sha: commit.sha
+          commit_sha: commit.sha,
+          state: params[:state]
         ).execute.with_api_entity_associations
 
         present paginate(commit_merge_requests), with: Entities::MergeRequestBasic
