@@ -4,8 +4,8 @@ module API
   module Entities
     class FeatureFlag < Grape::Entity
       class Scope < Grape::Entity
-        expose :id
-        expose :environment_scope
+        expose :id, documentation: { type: 'integer', example: 1 }
+        expose :environment_scope, documentation: { type: 'string', example: 'production' }
       end
     end
   end
