@@ -49,7 +49,10 @@ module API
 
           put 'authorize' do
             authorize_job_token_policies!(authorized_user_project)
-            authorize_workhorse!(**authorize_workhorse_params)
+
+            authorize_workhorse!(**authorize_workhorse_params).tap do
+              protect_package!(declared_params[:package_name], :generic)
+            end
           end
 
           desc 'Upload package file' do
@@ -92,12 +95,14 @@ module API
               file_name: encoded_file_name,
               build: current_authenticated_job
             )
+
             response = ::Packages::Generic::CreatePackageFileService
               .new(project, current_user, create_package_file_params)
               .execute
 
-            if response.error? && response.cause.package_file_already_exists?
-              bad_request!('Duplicate package is not allowed')
+            if response.error?
+              bad_request!('Duplicate package is not allowed') if response.cause.package_file_already_exists?
+              forbidden!('Package protected.') if response.cause.package_protected?
             end
 
             if params[:select] == 'package_file'
