@@ -12,11 +12,39 @@ module API
       helpers ::API::Helpers::Kubernetes::AgentHelpers
 
       namespace 'internal' do
+        namespace 'agents' do
+          namespace 'agentk' do
+            before do
+              check_agent_token
+            end
+
+            desc 'Gets agent info for agentk' do
+              detail 'Retrieves agent info for agentk for the given token'
+            end
+            route_setting :authentication, cluster_agent_token_allowed: true
+            get '/agent_info', feature_category: :deployment_management, urgency: :low do
+              project = agent.project
+
+              status 200
+              {
+                project_id: project.id,
+                agent_id: agent.id,
+                agent_name: agent.name,
+                gitaly_info: gitaly_info(project),
+                gitaly_repository: gitaly_repository(project),
+                default_branch: project.default_branch_or_main
+              }
+            end
+          end
+        end
+
         namespace 'kubernetes' do
           before do
             check_agent_token
           end
 
+          # TODO: Remove this endpoint once KAS points to the new endpoint - /internal/agents/agentk/agent_info
+          #       https://gitlab.com/gitlab-org/gitlab/-/issues/550719
           desc 'Gets agent info' do
             detail 'Retrieves agent info for the given token'
           end
@@ -35,24 +63,6 @@ module API
             }
           end
 
-          desc 'Gets project info' do
-            detail 'Retrieves project info (if authorized)'
-          end
-          route_setting :authentication, cluster_agent_token_allowed: true
-          get '/project_info', feature_category: :deployment_management, urgency: :low do
-            project = find_project(params[:id])
-
-            not_found! unless agent_has_access_to_project?(project)
-
-            status 200
-            {
-              project_id: project.id,
-              gitaly_info: gitaly_info(project),
-              gitaly_repository: gitaly_repository(project),
-              default_branch: project.default_branch_or_main
-            }
-          end
-
           desc 'Verify agent access to a project' do
             detail 'Verifies if the agent (owning the token) is authorized to access the given project'
           end
@@ -109,6 +119,8 @@ module API
             service_response = ::Clusters::Agents::AuthorizeProxyUserService.new(user, agent).execute
             render_api_error!(service_response[:message], service_response[:reason]) unless service_response.success?
 
+            set_feature_flag_header_for_agent(user: user, agent: agent)
+
             service_response.payload
           end
         end
