@@ -2,18 +2,20 @@
 
 module API
   class Issues < ::API::Base
-    include PaginationParams
+    include ::API::Concerns::AiWorkflowsAccess
+    include ::API::Concerns::McpAccess
     include APIGuard
+    include PaginationParams
+
+    allow_ai_workflows_access
+    allow_mcp_access_read
+    allow_mcp_access_create
 
     helpers Helpers::IssuesHelpers
     helpers SpammableActions::CaptchaCheck::RestApiActionsSupport
 
     before { authenticate_non_get! }
 
-    allow_access_with_scope :ai_workflows, if: ->(request) do
-      request.get? || request.head? || request.post? || request.put?
-    end
-
     feature_category :team_planning
     urgency :low
 
@@ -92,7 +94,6 @@ module API
         optional :due_date, type: String, values: %w[0 any today tomorrow overdue week month next_month_and_previous_two_weeks] << '',
           desc: 'Return issues that have no due date (`0`), or whose due date is this week, this month, between two weeks ago and next month, or which are overdue. Accepts: `overdue`, `week`, `month`, `next_month_and_previous_two_weeks`, `0`'
         optional :issue_type, type: String, values: WorkItems::Type.allowed_types_for_issues, desc: "The type of the issue. Accepts: #{WorkItems::Type.allowed_types_for_issues.join(', ')}"
-
         use :issues_stats_params
         use :pagination
       end
@@ -142,6 +143,7 @@ module API
         authenticate! unless params[:scope] == 'all'
         validate_search_rate_limit! if declared_params[:search].present?
         issues = paginate(find_issues)
+        issues = Ability.issues_readable_by_user(issues, current_user)
 
         options = {
           with: Entities::Issue,
@@ -215,10 +217,21 @@ module API
       end
       params do
         use :issues_params
+        optional :cursor, type: String, desc: 'Cursor for obtaining the next set of records'
       end
+      route_setting :authentication, job_token_allowed: true
+      route_setting :authorization,
+        job_token_policies: :read_work_items,
+        allow_public_access_for_enabled_project_features: :issues
       get ":id/issues" do
         validate_search_rate_limit! if declared_params[:search].present?
-        issues = paginate(find_issues(project_id: user_project.id))
+
+        if declared_params[:order_by] && Issue.supported_keyset_orderings.keys
+                                              .exclude?(declared_params[:order_by].to_sym)
+          params.delete("pagination")
+        end
+
+        issues = find_issues(project_id: user_project.id)
 
         options = {
           with: Entities::Issue,
@@ -228,7 +241,7 @@ module API
           include_subscribed: false
         }
 
-        present issues, options
+        present paginate_with_strategies(issues), options
       end
 
       desc 'Get statistics for the list of project issues'
@@ -247,6 +260,11 @@ module API
       params do
         requires :issue_iid, type: Integer, desc: 'The internal ID of a project issue'
       end
+      route_setting :mcp, tool_name: :get_issue, params: [:id, :issue_iid]
+      route_setting :authentication, job_token_allowed: true
+      route_setting :authorization,
+        job_token_policies: :read_work_items,
+        allow_public_access_for_enabled_project_features: :issues
       get ":id/issues/:issue_iid", as: :api_v4_project_issue do
         issue = find_project_issue(params[:issue_iid])
         present issue, with: Entities::Issue, current_user: current_user, project: user_project
@@ -268,6 +286,7 @@ module API
 
         use :issue_params
       end
+      route_setting :mcp, tool_name: :create_issue, params: Helpers::IssuesHelpers.create_issue_mcp_params
       post ':id/issues' do
         Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/21140')
 
@@ -440,7 +459,7 @@ module API
         authorize!(:destroy_issue, issue)
 
         destroy_conditionally!(issue) do |issue|
-          Issuable::DestroyService.new(container: user_project, current_user: current_user).execute(issue)
+          ::Issues::DestroyService.new(container: user_project, current_user: current_user).execute(issue)
         end
       end
       # rubocop: enable CodeReuse/ActiveRecord
