@@ -4,7 +4,10 @@ module Authn
   module TokenField
     class PrefixHelper
       def self.prepend_instance_prefix(prefix)
-        "#{instance_prefix}#{prefix}"
+        return prefix unless Feature.enabled?(:custom_prefix_for_all_token_types, :instance)
+        return prefix unless instance_prefix.present?
+
+        "#{instance_prefix}-#{prefix}"
       end
 
       def self.instance_prefix
@@ -14,15 +17,6 @@ module Authn
 
         Gitlab::CurrentSettings.current_application_settings.instance_token_prefix
       end
-
-      def self.default_instance_prefix(prefix)
-        return prefix unless Feature.enabled?(:custom_prefix_for_all_token_types, :instance)
-
-        return prefix unless prefix.starts_with?(instance_prefix)
-
-        # remove the configured instance prefix and add the default:
-        "#{ApplicationSetting.defaults[:instance_token_prefix]}#{prefix.delete_prefix(instance_prefix)}"
-      end
     end
   end
 end
