@@ -12,7 +12,7 @@ module Banzai
         self.object_class   = WorkItem
 
         def parent_records(parent, ids)
-          parent.work_items.where(iid: ids.to_a)
+          parent.work_items.iid_in(ids.to_a)
                 .includes(:project, :namespace, :work_item_type)
         end
 
