@@ -25,6 +25,7 @@ module Gitlab
           autocomplete_users_unauthenticated: { threshold: -> { application_settings.autocomplete_users_unauthenticated_limit }, interval: 1.minute },
           bulk_delete_todos: { threshold: 6, interval: 1.minute },
           bulk_import: { threshold: 6, interval: 1.minute },
+          ci_job_created_subscription: { threshold: 50, interval: 1.minute },
           code_suggestions_api_endpoint: { threshold: -> { application_settings.code_suggestions_api_rate_limit }, interval: 1.minute },
           create_organization_api: { threshold: -> { application_settings.create_organization_api_limit }, interval: 1.minute },
           delete_all_todos: { threshold: 1, interval: 5.minutes },
@@ -37,6 +38,7 @@ module Gitlab
           fetch_google_ip_list: { threshold: 10, interval: 1.minute },
           github_import: { threshold: 6, interval: 1.minute },
           fogbugz_import: { threshold: 1, interval: 1.minute },
+          gitea_import: { threshold: 1, interval: 1.minute },
           gitlab_shell_operation: { threshold: application_settings.gitlab_shell_operation_limit, interval: 1.minute },
           glql: { threshold: 1, interval: 15.minutes },
           group_api: { threshold: -> { application_settings.group_api_limit }, interval: 1.minute },
@@ -56,6 +58,7 @@ module Gitlab
           namespace_exists: { threshold: 20, interval: 1.minute },
           notes_create: { threshold: -> { application_settings.notes_create_limit }, interval: 1.minute },
           notification_emails: { threshold: 1000, interval: 1.day },
+          oauth_dynamic_registration: { threshold: 5, interval: 1.hour },
           permanent_email_failure: { threshold: 5, interval: 1.day },
           phone_verification_send_code: { threshold: 5, interval: 1.day },
           phone_verification_verify_code: { threshold: 5, interval: 1.day },
@@ -277,6 +280,8 @@ module Gitlab
                   strategy.increment(cache_key, expiry)
                 end
 
+        return false if value.nil?
+
         report_metrics(key, value, threshold_value, peek)
 
         value > threshold_value
