@@ -7,8 +7,8 @@ module Gitlab
         LoadError = Class.new(StandardError)
 
         class << self
-          def load!(content, inputs = {}, variables = [])
-            Loader.new(content, inputs: inputs, variables: variables).load.then do |result|
+          def load!(content, context, inputs = {})
+            Loader.new(content, inputs: inputs, context: context).load.then do |result|
               raise result.error_class, result.error if !result.valid? && result.error_class.present?
               raise LoadError, result.error unless result.valid?
 
