@@ -13,7 +13,10 @@ module Gitlab
         # rubocop: enable CodeReuse/ActiveRecord
 
         def execute
-          bulk_insert(Milestone, build_milestones)
+          rows, validation_errors = build_milestones
+
+          bulk_insert(rows)
+          bulk_insert_failures(validation_errors) if validation_errors.any?
           build_milestones_cache
         end
 
@@ -29,11 +32,11 @@ module Gitlab
           MilestoneFinder.new(project).build_cache
         end
 
-        def build(milestone)
+        def build_attributes(milestone)
           {
             iid: milestone[:number],
             title: milestone[:title],
-            description: milestone[:description],
+            description: description_for(milestone),
             project_id: project.id,
             state: state_for(milestone),
             due_date: milestone[:due_on]&.to_date,
@@ -42,6 +45,10 @@ module Gitlab
           }
         end
 
+        def description_for(milestone)
+          MarkdownText.format(milestone[:description], project: project, client: client)
+        end
+
         def state_for(milestone)
           milestone[:state] == 'open' ? :active : :closed
         end
@@ -53,6 +60,20 @@ module Gitlab
         def object_type
           :milestone
         end
+
+        private
+
+        def model
+          Milestone
+        end
+
+        def github_identifiers(milestone)
+          {
+            iid: milestone[:number],
+            title: milestone[:title],
+            object_type: object_type
+          }
+        end
       end
     end
   end
