@@ -5,6 +5,7 @@
 module Gitlab
   module GonHelper
     include WebpackHelper
+    include ::Organizations::OrganizationHelper
 
     def add_gon_variables
       gon.api_version                   = 'v4'
@@ -17,6 +18,7 @@ module Gitlab
       gon.user_color_scheme             = Gitlab::ColorSchemes.for_user(current_user).css_class
       gon.markdown_surround_selection   = current_user&.markdown_surround_selection
       gon.markdown_automatic_lists      = current_user&.markdown_automatic_lists
+      gon.markdown_maintain_indentation = current_user&.markdown_maintain_indentation
       gon.math_rendering_limits_enabled = Gitlab::CurrentSettings.math_rendering_limits_enabled
 
       add_browsersdk_tracking
@@ -33,7 +35,7 @@ module Gitlab
       gon.recaptcha_api_server_url = ::Recaptcha.configuration.api_server_url
       gon.recaptcha_sitekey      = Gitlab::CurrentSettings.recaptcha_site_key
       gon.gitlab_url             = Gitlab.config.gitlab.url
-      gon.promo_url              = ApplicationHelper.promo_url
+      gon.promo_url              = Gitlab::Routing.url_helpers.promo_url
       gon.forum_url              = Gitlab::Saas.community_forum_url
       gon.docs_url               = Gitlab::Saas.doc_url
       gon.revision               = Gitlab.revision
@@ -60,39 +62,54 @@ module Gitlab
 
       gon.diagramsnet_url = Gitlab::CurrentSettings.diagramsnet_url if Gitlab::CurrentSettings.diagramsnet_enabled
 
-      if current_user
-        gon.version = Gitlab::VERSION # publish version only for logged in users
-        gon.current_user_id = current_user.id
-        gon.current_username = current_user.username
-        gon.current_user_fullname = current_user.name
-        gon.current_user_avatar_url = current_user.avatar_url
-        gon.time_display_relative = current_user.time_display_relative
-        gon.time_display_format = current_user.time_display_format
-
-        if current_user.user_preference
-          gon.current_user_use_work_items_view = current_user.user_preference.use_work_items_view || false
-          gon.text_editor = current_user.user_preference.text_editor
-        end
+      if current_organization && ui_for_organizations_enabled?
+        gon.current_organization = current_organization.slice(:id, :name, :full_path, :web_url, :avatar_url)
       end
 
-      if current_organization && Feature.enabled?(:ui_for_organizations, current_user)
-        gon.current_organization = current_organization.slice(:id, :name, :web_url, :avatar_url)
-      end
+      add_gon_user_specific
+      add_gon_feature_flags
+    end
 
-      # Initialize gon.features with any flags that should be
-      # made globally available to the frontend
-      push_frontend_feature_flag(:ui_for_organizations, current_user)
+    def add_gon_user_specific
+      return unless current_user
+
+      gon.version = Gitlab::VERSION # publish version only for logged in users
+      gon.current_user_id = current_user.id
+      gon.current_username = current_user.username
+      gon.current_user_fullname = current_user.name
+      gon.current_user_avatar_url = current_user.avatar_url
+      gon.time_display_relative = current_user.time_display_relative
+      gon.time_display_format = current_user.time_display_format
+
+      return unless current_user.user_preference
+
+      gon.text_editor = current_user.user_preference.text_editor
+    end
+
+    # Initialize gon.features with any flags that should be
+    # made globally available to the frontend
+    def add_gon_feature_flags
+      # Use `push_to_gon_attributes` directly since we have a computed feature flag with
+      # an opt-out in ui_for_organizations_enabled?
+      push_to_gon_attributes(:features, :ui_for_organizations, ui_for_organizations_enabled?)
       push_frontend_feature_flag(:organization_switching, current_user)
       push_frontend_feature_flag(:find_and_replace, current_user)
       # To be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/399248
       push_frontend_feature_flag(:remove_monitor_metrics)
-      push_frontend_feature_flag(:work_items_view_preference, current_user)
       push_frontend_feature_flag(:work_item_view_for_issues)
-      push_frontend_feature_flag(:search_button_top_right, current_user)
-      push_frontend_feature_flag(:merge_request_dashboard, current_user, type: :wip)
+      push_frontend_feature_flag(:merge_request_dashboard, current_user, type: :beta)
       push_frontend_feature_flag(:new_project_creation_form, current_user, type: :wip)
       push_frontend_feature_flag(:work_items_client_side_boards, current_user)
       push_frontend_feature_flag(:glql_work_items, current_user, type: :wip)
+      push_frontend_feature_flag(:glql_aggregation, current_user, type: :wip)
+      push_frontend_feature_flag(:glql_typescript, current_user, type: :wip)
+      push_frontend_feature_flag(:whats_new_featured_carousel)
+      push_frontend_feature_flag(:extensible_reference_filters, current_user)
+      push_frontend_feature_flag(:paneled_view, current_user)
+      push_frontend_feature_flag(:disallow_immediate_deletion, current_user)
+
+      # Expose the Project Studio user preference as if it were a feature flag
+      push_force_frontend_feature_flag(:project_studio_enabled, Users::ProjectStudio.new(current_user).enabled?)
     end
 
     # Exposes the state of a feature flag to the frontend code.
