@@ -6,10 +6,17 @@
 
 module Gitlab
   module RequestForgeryProtection
-    # rubocop:disable Rails/ApplicationController
-    class Controller < ActionController::Base
+    class Controller < BaseActionController
       protect_from_forgery with: :exception, prepend: true
 
+      def initialize
+        super
+
+        # Squelch noisy and unnecessary "Can't verify CSRF token authenticity." messages.
+        # X-Csrf-Token is only one authentication mechanism for API helpers.
+        self.logger = ActiveSupport::Logger.new(File::NULL)
+      end
+
       def index
         head :ok
       end
@@ -26,12 +33,16 @@ module Gitlab
     def self.verified?(env)
       minimal_env = env.slice('REQUEST_METHOD', 'rack.session', 'HTTP_X_CSRF_TOKEN')
                       .merge('rack.input' => '')
+
+      # The CSRF token for some requests is in the form instead of headers.
+      # This line of code is used to accommodate this situation. See: https://gitlab.com/gitlab-org/gitlab/-/issues/443398
+      minimal_env['HTTP_X_CSRF_TOKEN'] ||= Rack::Request.new(env.dup).params['authenticity_token']
+
       call(minimal_env)
 
       true
     rescue ActionController::InvalidAuthenticityToken
       false
     end
-    # rubocop:enable Rails/ApplicationController
   end
 end
