@@ -7,6 +7,22 @@ module Gitlab
         Gitlab::Routing.url_helpers.help_page_path('ci/variables/_index.md', anchor: 'define-a-cicd-variable-in-the-ui')
       end
 
+      def self.vulnerability_checks_documentation_link
+        Gitlab::Routing.url_helpers.help_page_path('user/application_security/dast/browser/checks/_index.md')
+      end
+
+      def self.secure_log_level_documentation_link
+        Gitlab::Routing.url_helpers.help_page_path('user/application_security/dast/browser/troubleshooting.md',
+          anchor: 'secure_log_level')
+      end
+
+      def self.authentication_actions_documentation_link
+        Gitlab::Routing.url_helpers.help_page_path(
+          'user/application_security/dast/browser/configuration/authentication.md',
+          anchor: 'taking-additional-actions-after-submitting-the-login-form'
+        )
+      end
+
       # rubocop: disable Metrics/AbcSize -- Generate dynamic translation as per
       # https://docs.gitlab.com/ee/development/i18n/externalization.html#keep-translations-dynamic
       def self.data
@@ -33,11 +49,13 @@ module Gitlab
               additional: true,
               auth: true,
               type: "string",
-              example: "click(on=id:remember-me),click(on=css:.continue)",
+              example: "select(option=id:accept-yes),click(on=css:.continue)",
               name: s_("DastProfiles|After-login actions"),
-              description: s_(
-                "DastProfiles|A comma-separated list of actions to be run after login but before login " \
-                  "verification. Currently supports `click` actions."
+              description: format(s_(
+                "DastProfiles|A comma-separated list of actions to take after login but before login verification. " \
+                  "Supports `click` and `select` actions. " \
+                  "See [Taking additional actions after submitting the login form](%{documentation_link})."),
+                documentation_link: authentication_actions_documentation_link
               )
             },
             DAST_AUTH_BEFORE_LOGIN_ACTIONS: {
@@ -99,6 +117,37 @@ module Gitlab
                   "[Introduced](https://gitlab.com/gitlab-org/gitlab/-/issues/502476) in GitLab 17.6."
               )
             },
+            DAST_AUTH_OTP_FIELD: {
+              additional: true,
+              auth: true,
+              type: "selector",
+              example: "name:otp",
+              name: s_("DastProfiles|OTP field"),
+              description: s_(
+                "DastProfiles|A selector describing the element used to enter the one-time password on the login form."
+              )
+            },
+            DAST_AUTH_OTP_KEY: {
+              additional: false,
+              auth: true,
+              type: "String",
+              example: "I5UXITDBMIQEIQKTKQFA====",
+              name: s_("DastProfiles|OTP secret key"),
+              description: s_(
+                "DastProfiles|The Base32 encoded secret key to use when generating a one-time password to " \
+                  "authenticate to the website.")
+            },
+            DAST_AUTH_OTP_SUBMIT_FIELD: {
+              additional: true,
+              auth: true,
+              type: "selector",
+              example: "css:input[type=submit]",
+              name: s_("DastProfiles|OTP submit field"),
+              description: s_(
+                "DastProfiles|A selector describing the element that is clicked on to submit the OTP form " \
+                  "when it is separate from the username."
+              )
+            },
             DAST_AUTH_PASSWORD: {
               additional: false,
               auth: true,
@@ -132,11 +181,11 @@ module Gitlab
               additional: true,
               auth: true,
               type: "URL",
-              example: "https://www.site.com/welcome",
+              example: "https://www.site.com/welcome*",
               name: s_("DastProfiles|Success URL"),
               description: s_(
                 "DastProfiles|A URL that is compared to the URL in the browser to determine if authentication " \
-                  "has succeeded after the login form is submitted."
+                  "has succeeded after the login form is submitted. Wildcard `*` can be used to match a dynamic URL."
               )
             },
             DAST_AUTH_SUCCESS_IF_ELEMENT_FOUND: {
@@ -479,9 +528,10 @@ module Gitlab
               example: "/builds/project/urls.txt",
               name: s_("DastProfiles|Target paths file"),
               description: s_(
-                "DastProfiles|Ensures that the provided paths are always scanned. " \
+                "DastProfiles|Scan only these paths instead of crawling the whole site. " \
                   "Set to a file path containing a list of URL paths relative to `DAST_TARGET_URL`. " \
-                  "The file must be plain text with one path per line."
+                  "The file must be plain text with one path per line. When this is set, " \
+                  "`DAST_CRAWL_MAX_DEPTH` defaults to 1. To prevent this, set `DAST_OVERRIDE_MAX_DEPTH: false`."
               )
             },
             DAST_TARGET_PATHS: {
@@ -490,8 +540,9 @@ module Gitlab
               example: "/page1.html,/category1/page3.html",
               name: s_("DastProfiles|Target paths"),
               description: s_(
-                "DastProfiles|Ensures that the provided paths are always scanned. " \
-                  "Set to a comma-separated list of URL paths relative to `DAST_TARGET_URL`."
+                "DastProfiles|Scan only these paths instead of crawling the whole site. " \
+                  "Set to a comma-separated list of URL paths relative to `DAST_TARGET_URL`. When this is set, " \
+                  "`DAST_CRAWL_MAX_DEPTH` defaults to 1. To prevent this, set `DAST_OVERRIDE_MAX_DEPTH: false`."
               )
             },
             DAST_TARGET_URL: {
@@ -509,12 +560,13 @@ module Gitlab
               description: s_(
                 "DastProfiles|Set to `false` to disable caching. " \
                   "Default: `true`. " \
-                  "**Note:** Disabling cache can cause OOM events or DAST job timeouts."
+                  "**Note**: Disabling cache can cause OOM events or DAST job timeouts."
               )
             }
           },
           scanner: {
             DAST_AUTH_REPORT: {
+              additional: true,
               auth: true,
               type: "boolean",
               example: true,
@@ -527,24 +579,29 @@ module Gitlab
               )
             },
             DAST_CHECKS_TO_EXCLUDE: {
+              additional: true,
               type: "string",
               example: "552.2,78.1",
               name: s_("DastProfiles|Excluded checks"),
-              description: s_(
+              description: format(s_(
                 "DastProfiles|Comma-separated list of check identifiers to exclude from the scan. " \
-                  "For identifiers, see [vulnerability checks](../checks/_index.md)."
+                  "For identifiers, see [vulnerability checks](%{documentation_link})."),
+                documentation_link: vulnerability_checks_documentation_link
               )
             },
             DAST_CHECKS_TO_RUN: {
+              additional: true,
               type: "List of strings",
               example: "16.1,16.2,16.3",
               name: s_("DastProfiles|Included checks"),
-              description: s_(
+              description: format(s_(
                 "DastProfiles|Comma-separated list of check identifiers to use for the scan. " \
-                  "For identifiers, see [vulnerability checks](../checks/_index.md)."
+                  "For identifiers, see [vulnerability checks](%{documentation_link})."),
+                documentation_link: vulnerability_checks_documentation_link
               )
             },
             DAST_CRAWL_GRAPH: {
+              additional: true,
               type: "boolean",
               example: true,
               name: s_("DastProfiles|Generate graph"),
@@ -555,18 +612,21 @@ module Gitlab
               )
             },
             DAST_FULL_SCAN: {
+              additional: true,
               type: "boolean",
               example: true,
               name: s_("DastProfiles|Full scan"),
               description: s_("DastProfiles|Set to `true` to run both passive and active checks. Default is `false`.")
             },
             DAST_LOG_BROWSER_OUTPUT: {
+              additional: true,
               type: "boolean",
               example: true,
               name: s_("DastProfiles|Log browser output"),
               description: s_("DastProfiles|Set to `true` to log Chromium `STDOUT` and `STDERR`.")
             },
             DAST_LOG_CONFIG: {
+              additional: true,
               type: "List of strings",
               example: "brows:debug,auth:debug",
               name: s_("DastProfiles|Log levels"),
@@ -574,12 +634,14 @@ module Gitlab
                 "DastProfiles|A list of modules and their intended logging level for use in the console log.")
             },
             DAST_LOG_DEVTOOLS_CONFIG: {
+              additional: true,
               type: "string",
               example: "Default:messageAndBody,truncate:2000",
               name: s_("DastProfiles|Log messages"),
               description: s_("DastProfiles|Set to log protocol messages between DAST and the Chromium browser.")
             },
             DAST_LOG_FILE_CONFIG: {
+              additional: true,
               type: "List of strings",
               example: "brows:debug,auth:debug",
               name: s_("DastProfiles|Log file levels"),
@@ -587,24 +649,28 @@ module Gitlab
                 "DastProfiles|A list of modules and their intended logging level for use in the file log.")
             },
             DAST_LOG_FILE_PATH: {
+              additional: true,
               type: "string",
               example: "/output/browserker.log",
               name: s_("DastProfiles|Log file path"),
               description: s_("DastProfiles|Set to the path of the file log. Default is `gl-dast-scan.log`.")
             },
             SECURE_ANALYZERS_PREFIX: {
+              additional: true,
               type: "URL",
               example: "registry.organization.com",
               name: s_("DastProfiles|Docker registry"),
               description: s_("DastProfiles|Set the Docker registry base address from which to download the analyzer.")
             },
             SECURE_LOG_LEVEL: {
+              additional: true,
               type: "string",
               example: "debug",
               name: s_("DastProfiles|Default log level"),
-              description: s_(
+              description: format(s_(
                 "DastProfiles|Set the default level for the file log. " \
-                  "See [SECURE_LOG_LEVEL](../troubleshooting.md#secure_log_level)." \
+                  "See [SECURE_LOG_LEVEL](%{documentation_link})."),
+                documentation_link: secure_log_level_documentation_link
               )
             }
           }
@@ -613,7 +679,7 @@ module Gitlab
       # rubocop: enable Metrics/AbcSize
 
       def self.additional_site_variables
-        data[:site].filter { |_, variable| variable[:additional] }
+        data[:site].merge(data[:scanner]).filter { |_, variable| variable[:additional] }
       end
 
       def self.auth_variables
