@@ -2,7 +2,7 @@
 
 module Gitlab
   module Ssh
-    class Commit < Gitlab::SignedCommit
+    class Commit < Gitlab::Repositories::BaseSignedCommit
       private
 
       def signature_class
@@ -10,12 +10,14 @@ module Gitlab
       end
 
       def attributes
-        signature = ::Gitlab::Ssh::Signature.new(signature_text, signed_text, @commit.committer_email)
+        signature = ::Gitlab::Ssh::Signature.new(signature_text, signed_text, signer, @commit, author_email)
 
         {
           commit_sha: @commit.sha,
           project: @commit.project,
           key_id: signature.signed_by_key&.id,
+          key_fingerprint_sha256: signature.key_fingerprint,
+          user_id: signature.user_id,
           verification_status: signature.verification_status
         }
       end
