@@ -15,26 +15,36 @@ module Gitlab
           def initialize(metric_definition)
             super
 
-            raise ArgumentError, "options events are required" unless metric_events.present?
-          end
-
-          def metric_events
-            options[:events]
+            raise ArgumentError, "options events are required" unless event_names.present?
           end
 
           def value
             redis_usage_data do
-              event_params = time_constraints.merge(event_names: metric_events)
+              event_params = time_constraints.merge(event_names: event_names, property_name: property_name)
 
               Gitlab::UsageDataCounters::HLLRedisCounter.unique_events(**event_params)
             end
           end
 
-          def suggested_name
-            Gitlab::Usage::Metrics::NameSuggestion.for(:redis)
+          private
+
+          def event_names
+            # use `events:` attribute instead of `options:` attribute when possible
+            return options[:events] if events.empty?
+
+            events.pluck(:name)
           end
 
-          private
+          def property_name
+            return if events.empty?
+
+            uniques = events.pluck(:unique).uniq
+
+            return uniques.first if uniques.count == 1
+
+            message = "RedisHLLMetric for events #{events}, options #{options} has multiple unique_by values"
+            raise Gitlab::Usage::MetricDefinition::InvalidError, message
+          end
 
           def time_constraints
             case time_frame
