@@ -12,6 +12,9 @@ module Rouge
       def initialize(options = {})
         @tag = options[:tag]
         @line_number = options[:line_number] || 1
+        @fix_attributes = options[:fix_attributes]
+        @ellipsis_indexes = options[:ellipsis_indexes] || []
+        @ellipsis_svg = options[:ellipsis_svg]
       end
 
       def stream(tokens)
@@ -20,12 +23,21 @@ module Rouge
           yield "\n" unless is_first
           is_first = false
 
-          yield %(<span id="LC#{@line_number}" class="line" lang="#{@tag}">)
+          id = " id=\"LC#{@line_number}\"" unless @fix_attributes
+          lang = " lang=\"#{@tag}\"" unless @fix_attributes
+          data_lang = " data-lang=\"#{@tag}\"" if @fix_attributes && @tag
+
+          yield %(<span#{id} class="line"#{lang}#{data_lang}>)
 
           line.each do |token, value|
-            yield highlight_unicode_control_characters(span(token, value.chomp! || value))
+            value = value.chomp! || value
+            value = replace_space_characters(value)
+
+            yield highlight_unicode_control_characters(span(token, value))
           end
 
+          yield ellipsis if @ellipsis_indexes.include?(@line_number - 1) && @ellipsis_svg.present?
+
           yield %(</span>)
 
           @line_number += 1
@@ -34,6 +46,14 @@ module Rouge
 
       private
 
+      def ellipsis
+        %(<span class="gl-px-2 gl-rounded-base gl-mx-2 gl-bg-gray-100 gl-cursor-help has-tooltip" title="Content has been trimmed">#{@ellipsis_svg}</span>)
+      end
+
+      def replace_space_characters(text)
+        text.gsub(Gitlab::Unicode::SPACE_REGEXP, ' ')
+      end
+
       def highlight_unicode_control_characters(text)
         text.gsub(Gitlab::Unicode::BIDI_REGEXP) do |char|
           %(<span class="unicode-bidi has-tooltip" data-toggle="tooltip" title="#{Gitlab::Unicode.bidi_warning}">#{char}</span>)
