@@ -18,29 +18,34 @@ import (
 	"testing"
 	"time"
 
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/api"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/config"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/helper"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/proxy"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/testhelper"
-	"gitlab.com/gitlab-org/gitlab/workhorse/internal/upload/destination"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/upload/destination/objectstore/test"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/upstream/roundtripper"
 )
 
 var nilHandler = http.HandlerFunc(func(http.ResponseWriter, *http.Request) {})
 
+const (
+	urlPath = "/url/path"
+)
+
 type testFormProcessor struct{ SavedFileTracker }
 
-func (a *testFormProcessor) ProcessField(ctx context.Context, formName string, writer *multipart.Writer) error {
+func (a *testFormProcessor) ProcessField(_ context.Context, formName string, _ *multipart.Writer) error {
 	if formName != "token" && !strings.HasPrefix(formName, "file.") && !strings.HasPrefix(formName, "other.") {
 		return fmt.Errorf("illegal field: %v", formName)
 	}
 	return nil
 }
 
-func (a *testFormProcessor) Finalize(ctx context.Context) error {
+func (a *testFormProcessor) Finalize(_ context.Context) error {
 	return nil
 }
 
@@ -53,18 +58,21 @@ func TestUploadTempPathRequirement(t *testing.T) {
 
 func TestUploadHandlerForwardingRawData(t *testing.T) {
 	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`/url/path\z`), func(w http.ResponseWriter, r *http.Request) {
-		require.Equal(t, "PATCH", r.Method, "method")
+		assert.Equal(t, "PATCH", r.Method, "method")
 
 		body, err := io.ReadAll(r.Body)
-		require.NoError(t, err)
-		require.Equal(t, "REQUEST", string(body), "request body")
+		assert.NoError(t, err)
+		assert.Equal(t, "REQUEST", string(body), "request body")
 
 		w.WriteHeader(202)
 		fmt.Fprint(w, "RESPONSE")
 	})
 	defer ts.Close()
 
-	httpRequest, err := http.NewRequest("PATCH", ts.URL+"/url/path", bytes.NewBufferString("REQUEST"))
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	httpRequest, err := http.NewRequestWithContext(ctx, "PATCH", ts.URL+urlPath, bytes.NewBufferString("REQUEST"))
 	require.NoError(t, err)
 
 	tempPath := t.TempDir()
@@ -74,7 +82,7 @@ func TestUploadHandlerForwardingRawData(t *testing.T) {
 	fa := &eagerAuthorizer{&api.Response{TempPath: tempPath}}
 	preparer := &DefaultPreparer{}
 
-	interceptMultipartFiles(response, httpRequest, handler, nil, fa, preparer)
+	interceptMultipartFiles(response, httpRequest, handler, nil, fa, preparer, config.NewDefaultConfig())
 
 	require.Equal(t, 202, response.Code)
 	require.Equal(t, "RESPONSE", response.Body.String(), "response body")
@@ -85,19 +93,19 @@ func TestUploadHandlerRewritingMultiPartData(t *testing.T) {
 	tempPath := t.TempDir()
 
 	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`/url/path\z`), func(w http.ResponseWriter, r *http.Request) {
-		require.Equal(t, "PUT", r.Method, "method")
-		require.NoError(t, r.ParseMultipartForm(100000))
+		assert.Equal(t, "PUT", r.Method, "method")
+		assert.NoError(t, r.ParseMultipartForm(100000))
 
-		require.Empty(t, r.MultipartForm.File, "Expected to not receive any files")
-		require.Equal(t, "test", r.FormValue("token"), "Expected to receive token")
-		require.Equal(t, "my.file", r.FormValue("file.name"), "Expected to receive a filename")
+		assert.Empty(t, r.MultipartForm.File, "Expected to not receive any files")
+		assert.Equal(t, "test", r.FormValue("token"), "Expected to receive token")
+		assert.Equal(t, "my.file", r.FormValue("file.name"), "Expected to receive a filename")
 
 		filePath = r.FormValue("file.path")
-		require.True(t, strings.HasPrefix(filePath, tempPath), "Expected to the file to be in tempPath")
+		assert.True(t, strings.HasPrefix(filePath, tempPath), "Expected to the file to be in tempPath")
 
-		require.Empty(t, r.FormValue("file.remote_url"), "Expected to receive empty remote_url")
-		require.Empty(t, r.FormValue("file.remote_id"), "Expected to receive empty remote_id")
-		require.Equal(t, "4", r.FormValue("file.size"), "Expected to receive the file size")
+		assert.Empty(t, r.FormValue("file.remote_url"), "Expected to receive empty remote_url")
+		assert.Empty(t, r.FormValue("file.remote_id"), "Expected to receive empty remote_id")
+		assert.Equal(t, "4", r.FormValue("file.size"), "Expected to receive the file size")
 
 		hashes := map[string]string{
 			"sha1":   "a94a8fe5ccb19ba61c4c0873d391e987982fbbd3",
@@ -106,23 +114,18 @@ func TestUploadHandlerRewritingMultiPartData(t *testing.T) {
 		}
 
 		for algo, hash := range hashes {
-			require.Equal(t, hash, r.FormValue("file."+algo), "file hash %s", algo)
+			assert.Equal(t, hash, r.FormValue("file."+algo), "file hash %s", algo)
 		}
 
 		expectedLen := 12
 
-		if destination.FIPSEnabled() {
-			expectedLen--
-			require.Empty(t, r.FormValue("file.md5"), "file hash md5")
-		} else {
-			require.Equal(t, "098f6bcd4621d373cade4e832627b4f6", r.FormValue("file.md5"), "file hash md5")
-		}
-
-		require.Len(t, r.MultipartForm.Value, expectedLen, "multipart form values")
+		assert.Equal(t, "098f6bcd4621d373cade4e832627b4f6", r.FormValue("file.md5"), "file hash md5")
+		assert.Len(t, r.MultipartForm.Value, expectedLen, "multipart form values")
 
 		w.WriteHeader(202)
 		fmt.Fprint(w, "RESPONSE")
 	})
+	defer ts.Close()
 
 	var buffer bytes.Buffer
 
@@ -133,11 +136,10 @@ func TestUploadHandlerRewritingMultiPartData(t *testing.T) {
 	fmt.Fprint(file, "test")
 	writer.Close()
 
-	httpRequest, err := http.NewRequest("PUT", ts.URL+"/url/path", nil)
+	ctx, cancel := context.WithCancel(context.Background())
+	httpRequest, err := http.NewRequestWithContext(ctx, "PUT", ts.URL+urlPath, nil)
 	require.NoError(t, err)
 
-	ctx, cancel := context.WithCancel(context.Background())
-	httpRequest = httpRequest.WithContext(ctx)
 	httpRequest.Body = io.NopCloser(&buffer)
 	httpRequest.ContentLength = int64(buffer.Len())
 	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
@@ -148,7 +150,7 @@ func TestUploadHandlerRewritingMultiPartData(t *testing.T) {
 	fa := &eagerAuthorizer{&api.Response{TempPath: tempPath}}
 	preparer := &DefaultPreparer{}
 
-	interceptMultipartFiles(response, httpRequest, handler, &testFormProcessor{}, fa, preparer)
+	interceptMultipartFiles(response, httpRequest, handler, &testFormProcessor{}, fa, preparer, config.NewDefaultConfig())
 	require.Equal(t, 202, response.Code)
 
 	cancel() // this will trigger an async cleanup
@@ -183,11 +185,12 @@ func TestUploadHandlerDetectingInjectedMultiPartData(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 			ts := testhelper.TestServerWithHandler(regexp.MustCompile(`/url/path\z`), func(w http.ResponseWriter, r *http.Request) {
-				require.Equal(t, "PUT", r.Method, "method")
+				assert.Equal(t, "PUT", r.Method, "method")
 
 				w.WriteHeader(202)
 				fmt.Fprint(w, "RESPONSE")
 			})
+			defer ts.Close()
 
 			var buffer bytes.Buffer
 
@@ -199,11 +202,12 @@ func TestUploadHandlerDetectingInjectedMultiPartData(t *testing.T) {
 			writer.WriteField(test.field, "value")
 			writer.Close()
 
-			httpRequest, err := http.NewRequest("PUT", ts.URL+"/url/path", &buffer)
+			ctx, cancel := context.WithCancel(context.Background())
+			defer cancel()
+
+			httpRequest, err := http.NewRequestWithContext(ctx, "PUT", ts.URL+urlPath, &buffer)
 			require.NoError(t, err)
 
-			ctx, cancel := context.WithCancel(context.Background())
-			httpRequest = httpRequest.WithContext(ctx)
 			httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
 			response := httptest.NewRecorder()
 
@@ -212,7 +216,6 @@ func TestUploadHandlerDetectingInjectedMultiPartData(t *testing.T) {
 			testInterceptMultipartFiles(t, response, httpRequest, handler, &testFormProcessor{})
 			require.Equal(t, test.response, response.Code)
 
-			cancel() // this will trigger an async cleanup
 			waitUntilDeleted(t, filePath)
 		})
 	}
@@ -225,7 +228,10 @@ func TestUploadProcessingField(t *testing.T) {
 	writer.WriteField("token2", "test")
 	writer.Close()
 
-	httpRequest, err := http.NewRequest("PUT", "/url/path", &buffer)
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	httpRequest, err := http.NewRequestWithContext(ctx, "PUT", urlPath, &buffer)
 	require.NoError(t, err)
 	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
 
@@ -239,20 +245,11 @@ func TestUploadProcessingField(t *testing.T) {
 func TestUploadingMultipleFiles(t *testing.T) {
 	testhelper.ConfigureSecret()
 
-	var buffer bytes.Buffer
+	httpRequest, response := setupMultipleFiles(t)
 
-	writer := multipart.NewWriter(&buffer)
-	for i := 0; i < 11; i++ {
-		_, err := writer.CreateFormFile(fmt.Sprintf("file %v", i), "my.file")
-		require.NoError(t, err)
-	}
-	require.NoError(t, writer.Close())
-
-	httpRequest, err := http.NewRequest("PUT", "/url/path", &buffer)
-	require.NoError(t, err)
-	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
-
-	response := httptest.NewRecorder()
+	ctx, cancel := context.WithCancel(context.Background())
+	httpRequest = httpRequest.WithContext(ctx)
+	defer cancel()
 
 	testInterceptMultipartFiles(t, response, httpRequest, nilHandler, &testFormProcessor{})
 
@@ -267,7 +264,7 @@ func TestUploadProcessingFile(t *testing.T) {
 	objectStore, testServer := test.StartObjectStore()
 	defer testServer.Close()
 
-	storeUrl := testServer.URL + test.ObjectPath
+	storeURL := testServer.URL + test.ObjectPath
 
 	tests := []struct {
 		name    string
@@ -288,7 +285,7 @@ func TestUploadProcessingFile(t *testing.T) {
 		},
 		{
 			name:    "ObjectStore Upload",
-			preauth: &api.Response{RemoteObject: api.RemoteObject{StoreURL: storeUrl, ID: "123"}},
+			preauth: &api.Response{RemoteObject: api.RemoteObject{StoreURL: storeURL, ID: "123"}},
 			content: func(*testing.T) []byte { return objectStore.GetObject(test.ObjectPath) },
 		},
 	}
@@ -302,7 +299,10 @@ func TestUploadProcessingFile(t *testing.T) {
 			fmt.Fprint(file, "test")
 			writer.Close()
 
-			httpRequest, err := http.NewRequest("PUT", "/url/path", &buffer)
+			ctx, cancel := context.WithCancel(context.Background())
+			defer cancel()
+
+			httpRequest, err := http.NewRequestWithContext(ctx, "PUT", urlPath, &buffer)
 			require.NoError(t, err)
 			httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
 
@@ -310,7 +310,7 @@ func TestUploadProcessingFile(t *testing.T) {
 			fa := &eagerAuthorizer{test.preauth}
 			preparer := &DefaultPreparer{}
 
-			interceptMultipartFiles(response, httpRequest, nilHandler, &testFormProcessor{}, fa, preparer)
+			interceptMultipartFiles(response, httpRequest, nilHandler, &testFormProcessor{}, fa, preparer, config.NewDefaultConfig())
 
 			require.Equal(t, 200, response.Code)
 			require.Equal(t, "test", string(test.content(t)))
@@ -342,7 +342,10 @@ func TestInvalidFileNames(t *testing.T) {
 		fmt.Fprint(file, "test")
 		writer.Close()
 
-		httpRequest, err := http.NewRequest("POST", "/example", buffer)
+		ctx, cancel := context.WithCancel(context.Background())
+		defer cancel()
+
+		httpRequest, err := http.NewRequestWithContext(ctx, "POST", "/example", buffer)
 		require.NoError(t, err)
 		httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
 
@@ -352,6 +355,90 @@ func TestInvalidFileNames(t *testing.T) {
 	}
 }
 
+func TestIncompleteMultipartData(t *testing.T) {
+	testhelper.ConfigureSecret()
+
+	buffer := &bytes.Buffer{}
+
+	writer := multipart.NewWriter(buffer)
+	file, err := writer.CreateFormFile("file", "somefile.txt")
+	require.NoError(t, err)
+	fmt.Fprint(file, "test")
+	writer.Close()
+
+	// Truncate the buffer to simulate an incomplete multipart request
+	truncatedBuffer := buffer.Bytes()[:buffer.Len()-1]
+	customReader := bytes.NewReader(truncatedBuffer)
+
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	httpRequest, err := http.NewRequestWithContext(ctx, "POST", "/example", customReader)
+	require.NoError(t, err)
+	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
+
+	response := httptest.NewRecorder()
+	testInterceptMultipartFiles(t, response, httpRequest, nilHandler, &SavedFileTracker{Request: httpRequest})
+	require.Equal(t, 400, response.Code)
+}
+
+func TestBadMultipartHeader(t *testing.T) {
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	httpRequest, err := http.NewRequestWithContext(ctx, "POST", "/example", bytes.NewReader(nil))
+	require.NoError(t, err)
+
+	// Invalid header: missing boundary
+	httpRequest.Header.Set("Content-Type", "multipart/form-data")
+
+	response := httptest.NewRecorder()
+	testInterceptMultipartFiles(t, response, httpRequest, nilHandler, &SavedFileTracker{Request: httpRequest})
+	require.Equal(t, 400, response.Code)
+}
+
+func TestUnauthorizedMultipartHeader(t *testing.T) {
+	testhelper.ConfigureSecret()
+
+	httpRequest, response := setupMultipleFiles(t)
+
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
+		w.WriteHeader(http.StatusUnauthorized)
+	}))
+	defer ts.Close()
+
+	api := api.NewAPI(helper.URLMustParse(ts.URL), "123", http.DefaultTransport)
+	interceptMultipartFiles(response, httpRequest, nilHandler, &testFormProcessor{}, &apiAuthorizer{api}, &DefaultPreparer{}, config.NewDefaultConfig())
+
+	require.Equal(t, 401, response.Code)
+	require.Equal(t, "401 Unauthorized\n", response.Body.String())
+}
+
+func TestMalformedMimeHeader(t *testing.T) {
+	testhelper.ConfigureSecret()
+
+	h := make(textproto.MIMEHeader)
+	h.Set("Invalid Header Line\r\nContent-Type", "text/plain\r\n\r\n")
+
+	buffer := &bytes.Buffer{}
+	writer := multipart.NewWriter(buffer)
+	file, err := writer.CreatePart(h)
+	require.NoError(t, err)
+	fmt.Fprint(file, "test")
+	writer.Close()
+
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	httpRequest, err := http.NewRequestWithContext(ctx, "POST", "/example", buffer)
+	require.NoError(t, err)
+	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
+
+	response := httptest.NewRecorder()
+	testInterceptMultipartFiles(t, response, httpRequest, nilHandler, &SavedFileTracker{Request: httpRequest})
+	require.Equal(t, 400, response.Code)
+}
+
 func TestContentDispositionRewrite(t *testing.T) {
 	testhelper.ConfigureSecret()
 
@@ -398,7 +485,7 @@ func TestContentDispositionRewrite(t *testing.T) {
 			httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
 
 			var upstreamRequestBuffer bytes.Buffer
-			customHandler := http.HandlerFunc(func(rw http.ResponseWriter, r *http.Request) {
+			customHandler := http.HandlerFunc(func(_ http.ResponseWriter, r *http.Request) {
 				r.Write(&upstreamRequestBuffer)
 			})
 
@@ -414,7 +501,7 @@ func TestContentDispositionRewrite(t *testing.T) {
 			for i := 0; ; i++ {
 				p, err := reader.NextPart()
 				if err == io.EOF {
-					require.Equal(t, i, 1)
+					require.Equal(t, 1, i)
 					break
 				}
 				require.NoError(t, err)
@@ -432,12 +519,12 @@ func TestUploadHandlerRemovingExif(t *testing.T) {
 
 	runUploadTest(t, content, "sample_exif.jpg", 200, func(w http.ResponseWriter, r *http.Request) {
 		err := r.ParseMultipartForm(100000)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 
 		size, err := strconv.Atoi(r.FormValue("file.size"))
-		require.NoError(t, err)
-		require.True(t, size < len(content), "Expected the file to be smaller after removal of exif")
-		require.True(t, size > 0, "Expected to receive not empty file")
+		assert.NoError(t, err)
+		assert.Less(t, size, len(content), "Expected the file to be smaller after removal of exif")
+		assert.Positive(t, size, 0, "Expected to receive non-empty file")
 
 		w.WriteHeader(200)
 		fmt.Fprint(w, "RESPONSE")
@@ -450,12 +537,12 @@ func TestUploadHandlerRemovingExifTiff(t *testing.T) {
 
 	runUploadTest(t, content, "sample_exif.tiff", 200, func(w http.ResponseWriter, r *http.Request) {
 		err := r.ParseMultipartForm(100000)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 
 		size, err := strconv.Atoi(r.FormValue("file.size"))
-		require.NoError(t, err)
-		require.True(t, size < len(content), "Expected the file to be smaller after removal of exif")
-		require.True(t, size > 0, "Expected to receive not empty file")
+		assert.NoError(t, err)
+		assert.Less(t, size, len(content), "Expected the file to be smaller after removal of exif")
+		assert.Positive(t, size, 0, "Expected to receive not empty file")
 
 		w.WriteHeader(200)
 		fmt.Fprint(w, "RESPONSE")
@@ -468,11 +555,11 @@ func TestUploadHandlerRemovingExifInvalidContentType(t *testing.T) {
 
 	runUploadTest(t, content, "sample_exif_invalid.jpg", 200, func(w http.ResponseWriter, r *http.Request) {
 		err := r.ParseMultipartForm(100000)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 
 		output, err := os.ReadFile(r.FormValue("file.path"))
-		require.NoError(t, err)
-		require.Equal(t, content, output, "Expected the file to be same as before")
+		assert.NoError(t, err)
+		assert.Equal(t, content, output, "Expected the file to be same as before")
 
 		w.WriteHeader(200)
 		fmt.Fprint(w, "RESPONSE")
@@ -483,9 +570,9 @@ func TestUploadHandlerRemovingExifCorruptedFile(t *testing.T) {
 	content, err := os.ReadFile("exif/testdata/sample_exif_corrupted.jpg")
 	require.NoError(t, err)
 
-	runUploadTest(t, content, "sample_exif_corrupted.jpg", 422, func(w http.ResponseWriter, r *http.Request) {
+	runUploadTest(t, content, "sample_exif_corrupted.jpg", 422, func(_ http.ResponseWriter, r *http.Request) {
 		err := r.ParseMultipartForm(100000)
-		require.Error(t, err)
+		assert.Error(t, err)
 	})
 }
 
@@ -505,12 +592,12 @@ func runUploadTest(t *testing.T, image []byte, filename string, httpCode int, ts
 	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`/url/path\z`), tsHandler)
 	defer ts.Close()
 
-	httpRequest, err := http.NewRequest("POST", ts.URL+"/url/path", &buffer)
-	require.NoError(t, err)
-
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
 
+	httpRequest, err := http.NewRequestWithContext(ctx, "POST", ts.URL+urlPath, &buffer)
+	require.NoError(t, err)
+
 	httpRequest = httpRequest.WithContext(ctx)
 	httpRequest.ContentLength = int64(buffer.Len())
 	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
@@ -542,5 +629,24 @@ func testInterceptMultipartFiles(t *testing.T, w http.ResponseWriter, r *http.Re
 	fa := &eagerAuthorizer{&api.Response{TempPath: t.TempDir()}}
 	preparer := &DefaultPreparer{}
 
-	interceptMultipartFiles(w, r, h, filter, fa, preparer)
+	interceptMultipartFiles(w, r, h, filter, fa, preparer, config.NewDefaultConfig())
+}
+
+func setupMultipleFiles(t *testing.T) (*http.Request, *httptest.ResponseRecorder) {
+	var buffer bytes.Buffer
+
+	t.Helper()
+
+	writer := multipart.NewWriter(&buffer)
+	for i := 0; i < 11; i++ {
+		_, err := writer.CreateFormFile(fmt.Sprintf("file %v", i), "my.file")
+		require.NoError(t, err)
+	}
+	require.NoError(t, writer.Close())
+
+	httpRequest, err := http.NewRequest("PUT", urlPath, &buffer)
+	require.NoError(t, err)
+	httpRequest.Header.Set("Content-Type", writer.FormDataContentType())
+
+	return httpRequest, httptest.NewRecorder()
 }
